import './async-D55cHugf.js';
import { d as bind_props } from './index-K3l_dLem.js';
import { M as MarkdownCode } from './MarkdownCode-DlJpAOAo.js';

/* empty css                                         */
function Info($$renderer, $$props) {
  let info = $$props["info"];
  $$renderer.push(`<div class="svelte-9hc4ua">`);
  MarkdownCode($$renderer, { message: info, sanitize_html: true });
  $$renderer.push(`<!----></div>`);
  bind_props($$props, { info });
}

export { Info as I };
//# sourceMappingURL=Info-BG_G1YGk.js.map
