
	input.svelte-3g0mcl {
		--ring-color: transparent;
		position: relative;
		box-shadow: var(--input-shadow);
		border: 1px solid var(--checkbox-border-color);
		border-radius: var(--radius-xs);
		background-color: var(--checkbox-background-color);
		line-height: var(--line-sm);
		width: 18px !important;
		height: 18px !important;
	}

	input.svelte-3g0mcl:checked,
	input.svelte-3g0mcl:checked:hover,
	input.svelte-3g0mcl:checked:focus {
		border-color: var(--checkbox-border-color-selected);
		background-image: var(--checkbox-check);
		background-color: var(--checkbox-background-color-selected);
	}

	input.svelte-3g0mcl:hover {
		border-color: var(--checkbox-border-color-hover);
		background-color: var(--checkbox-background-color-hover);
	}

	input.svelte-3g0mcl:focus {
		border-color: var(--checkbox-border-color-focus);
		background-color: var(--checkbox-background-color-focus);
	}

	.disabled.svelte-3g0mcl {
		opacity: 0.8 !important;
		cursor: not-allowed;
	}
	.icon.svelte-6im0c4 {
		display: inline-block;
		width: 18px;
		height: 18px;
		padding: 3px 2px 3px 3px;
		margin: 0;
		flex-grow: 0;
		display: inline-flex;
		justify-content: center;
		align-items: center;
		border-radius: 2px;
		cursor: pointer;
		transition: 0.1s;
		flex-shrink: 0;
	}

	.file-icon.svelte-6im0c4 {
		display: inline-block;
		height: 20px;
		margin-left: -1px;
		margin: 0;
		flex-grow: 0;
		display: inline-flex;
		justify-content: center;
		align-items: center;

		transition: 0.1s;
	}

	.file-icon.svelte-6im0c4 img:where(.svelte-6im0c4) {
		width: 100%;
		height: 100%;
	}

	.icon.svelte-6im0c4:hover {
		background: #eee;
	}

	.icon.svelte-6im0c4:hover > * {
		color: var(--block-info-text-color);
	}

	.icon.svelte-6im0c4 > * {
		transform: rotate(90deg);
		transform-origin: 40% 50%;
		transition: 0.2s;
		color: var(--color-accent);
	}

	.no-checkbox.svelte-6im0c4 {
		width: 18px;
		height: 18px;
	}

	ul.root.svelte-6im0c4 .no-checkbox:where(.svelte-6im0c4) {
		display: none;
	}

	.hidden.svelte-6im0c4 > * {
		transform: rotate(0);
		color: var(--body-text-color-subdued);
	}

	ul.svelte-6im0c4 {
		margin-left: 26px;
		padding-left: 0;
		list-style: none;
	}

	ul.root.svelte-6im0c4 {
		margin-left: 8px;
	}

	ul.no-checkboxes.svelte-6im0c4:not(.root) {
		margin-left: 20px;
	}

	li.svelte-6im0c4 {
		margin-left: 0;
		padding-left: 0;
		align-items: center;
		margin: 8px 0;
		font-family: var(--font-mono);
		font-size: var(--scale-00);
		overflow-wrap: anywhere;
		word-break: break-word;
	}

	.wrap.svelte-6im0c4 {
		display: flex;
		gap: 8px;
		align-items: center;
	}

	.wrap.selected.svelte-6im0c4 {
		background-color: var(--color-accent-soft);
		border-radius: var(--radius-sm);
		margin-left: -4px;
		padding-left: 4px;
	}

	.wrap.selectable.svelte-6im0c4 {
		cursor: pointer;
		border-radius: var(--radius-sm);
		margin-left: -4px;
		padding-left: 4px;
		padding-right: 4px;
	}

	.wrap.selectable.svelte-6im0c4:hover {
		background-color: var(--border-color-accent);
	}

	.item-name.svelte-6im0c4 {
		flex: 1;
		padding: 2px 4px;
		border-radius: var(--radius-sm);
		margin-right: -4px;
	}
	.file-wrap.svelte-1gs1iku {
		height: calc(100% - 25px);
		overflow-y: scroll;
	}