
	.minimal-audio-recorder.svelte-doy9oc {
		display: flex;
		align-items: center;
		gap: var(--spacing-sm);
		border-radius: var(--radius-sm);
		width: 100%;
		padding: var(--spacing-sm);
	}

	.device-selection-wrapper.svelte-doy9oc {
		display: flex;
		flex-direction: row;
		align-items: center;
		justify-content: center;
		gap: var(--spacing-md);
		width: 100%;
	}

	.waveform-wrapper.svelte-doy9oc {
		flex: 1 1 auto;
		min-width: 0;
		width: 100%;
	}

	.waveform-wrapper.svelte-doy9oc ::part(wrapper) {
		margin-bottom: 0;
	}

	.timestamp.svelte-doy9oc {
		font-size: 13px;
		font-weight: 500;
		color: var(--body-text-color);
		opacity: 0.7;
		font-variant-numeric: tabular-nums;
		flex-shrink: 0;
		min-width: 40px;
		text-align: center;
	}

	.device-select-large.svelte-doy9oc {
		max-width: var(--size-60);
		font-size: var(--text-sm);
		padding: var(--spacing-sm) var(--spacing-md);
		border: 1px solid var(--border-color-primary);
		border-radius: var(--radius-md);
		background: var(--background-fill-secondary);
		color: var(--body-text-color);
		cursor: pointer;
		height: var(--size-9);
	}

	.record-button.svelte-doy9oc {
		display: flex;
		align-items: center;
		justify-content: center;
		height: var(--size-9);
		width: var(--size-9);
		padding: 0;
		flex-shrink: 0;
		background-color: var(--block-background-fill);
		color: var(--body-text-color);
		border: 1px solid var(--border-color-primary);
		border-radius: var(--radius-md);
		cursor: pointer;
	}

	.record-button.svelte-doy9oc::before {
		content: "";
		height: var(--size-4);
		width: var(--size-4);
		border-radius: var(--radius-full);
		background: var(--primary-600);
		flex-shrink: 0;
	}

	.record-button.svelte-doy9oc:hover {
		background-color: var(--block-background-fill);
		border-color: var(--border-color-accent);
	}

	.record-button.svelte-doy9oc:active {
		transform: scale(0.98);
	}

	.stop-button.svelte-doy9oc {
		display: flex;
		align-items: center;
		justify-content: center;
		width: var(--size-9);
		height: var(--size-9);
		padding: 0;
		border: var(--size-px) solid var(--border-color-primary);
		border-radius: var(--radius-md);
		background: var(--button-secondary-background-fill);
		color: var(--error-500);
		cursor: pointer;
		flex-shrink: 0;
	}

	.stop-button.svelte-doy9oc:hover {
		background: var(--button-secondary-background-fill-hover);
		color: var(--error-600);
	}

	.stop-button.svelte-doy9oc:active {
		transform: scale(0.95);
	}

	.stop-button.svelte-doy9oc svg {
		width: var(--size-5);
		height: var(--size-5);
	}

	@media (prefers-reduced-motion: reduce) {
		/* (unused) .record-btn {
			transition: none;
		}*/
		/* (unused) .record-btn.recording {
			animation: none;
		}*/
	}

	@media (max-width: 768px) {
		.device-select-large.svelte-doy9oc {
			max-width: var(--size-40);
		}
	}
	.full-container.svelte-1qn0337 {
		width: 100%;
		position: relative;
		padding: var(--block-padding);
		border: 1px solid transparent;
	}

	.full-container.dragging.svelte-1qn0337 {
		border-color: var(--color-accent);
		border-radius: calc(var(--radius-sm) - var(--size-px));
	}

	.full-container.dragging.svelte-1qn0337::after {
		content: "";
		position: absolute;
		inset: 0;
		pointer-events: none;
	}

	.input-container.svelte-1qn0337 {
		display: flex;
		position: relative;
		flex-direction: column;
		gap: 0;
	}

	.input-wrapper.svelte-1qn0337 {
		display: flex;
		position: relative;
		flex-direction: column;
		gap: 0;
		background: var(--block-background-fill);
		border-radius: var(--radius-xl);
		padding: var(--spacing-sm) var(--spacing-sm) var(--spacing-sm) 0;
		align-items: flex-start;
		min-height: auto;
	}

	.input-wrapper.has-files.svelte-1qn0337 {
		padding-top: var(--spacing-xs);
	}

	.input-row.svelte-1qn0337 {
		display: flex;
		align-items: flex-start;
		gap: var(--spacing-sm);
		width: 100%;
	}

	.thumbnails.svelte-1qn0337 {
		display: flex;
		align-items: center;
		gap: var(--spacing-sm);
		padding: var(--spacing-xs) 0;
		margin-bottom: var(--spacing-xs);
		overflow-x: auto;
		overflow-y: hidden;
		scrollbar-width: none;
		-ms-overflow-style: none;
		flex-wrap: nowrap;
		-webkit-overflow-scrolling: touch;
		scroll-behavior: smooth;
		overflow-y: scroll;
		width: 100%;
	}

	.thumbnails.svelte-1qn0337::-webkit-scrollbar,
	.thumbnails.svelte-1qn0337::-webkit-scrollbar-track,
	.thumbnails.svelte-1qn0337::-webkit-scrollbar-thumb {
		display: none;
	}

	.thumbnails.svelte-1qn0337 img {
		width: var(--size-full);
		height: var(--size-full);
		object-fit: cover;
		border-radius: var(--radius-md);
	}

	.thumbnail-wrapper.svelte-1qn0337 {
		position: relative;
		flex-shrink: 0;
	}

	.thumbnail-item.svelte-1qn0337 {
		position: relative;
		display: flex;
		justify-content: center;
		align-items: center;
		border-radius: var(--radius-md);
		background: var(--background-fill-secondary);
		width: var(--size-full);
		height: var(--size-full);
		cursor: default;
		padding: 0;
	}

	.thumbnail-small.svelte-1qn0337 {
		width: var(--size-10);
		height: var(--size-10);
	}

	.thumbnail-item.svelte-1qn0337 svg {
		width: var(--size-5);
		height: var(--size-5);
	}

	.delete-button.svelte-1qn0337 {
		position: absolute;
		inset: 0;
		display: flex;
		justify-content: center;
		align-items: center;
		color: var(--button-primary-text-color);
		background: rgba(0, 0, 0, 0.6);
		backdrop-filter: var(--blur-xs);
		border-radius: var(--radius-md);
		padding: 0;
		z-index: var(--layer-1);
		opacity: 0;
		transition: opacity 0.1s var(--easing-standard);
	}

	.delete-button.svelte-1qn0337:hover {
		background: rgba(0, 0, 0, 0.8);
	}

	.delete-button.svelte-1qn0337 svg {
		width: var(--size-5);
		height: var(--size-5);
	}

	.thumbnail-item.svelte-1qn0337:hover .delete-button:where(.svelte-1qn0337) {
		opacity: 1;
	}

	textarea.svelte-1qn0337 {
		flex-grow: 1;
		outline: none !important;
		background: transparent;
		padding: var(--spacing-sm) 0;
		color: var(--body-text-color);
		font-weight: var(--input-text-weight);
		font-size: var(--input-text-size);
		border: none;
		margin: 0;
		resize: none;
		position: relative;
		z-index: var(--layer-1);
		text-align: left;
	}

	textarea.svelte-1qn0337:disabled {
		-webkit-opacity: 1;
		opacity: 1;
	}

	textarea.svelte-1qn0337::placeholder {
		color: var(--input-placeholder-color);
	}

	textarea[dir="rtl"].svelte-1qn0337 {
		text-align: right;
	}

	/* (unused) textarea[dir="rtl"] ~ .submit-button :global(svg) {
		transform: scaleX(-1);
	}*/

	.microphone-button.svelte-1qn0337,
	.icon-button.svelte-1qn0337 {
		color: var(--body-text-color);
		cursor: pointer;
		padding: var(--spacing-sm);
		display: flex;
		justify-content: center;
		align-items: center;
		flex-shrink: 0;
		border-radius: var(--radius-md);
	}

	.thumbnail-add.svelte-1qn0337 {
		background: var(--button-secondary-background-fill);
		cursor: pointer;
		display: flex;
		justify-content: center;
		align-items: center;
		flex-shrink: 0;
		width: var(--size-10);
		height: var(--size-10);
		border-radius: var(--radius-md);
		z-index: var(--layer-1);
	}

	.thumbnail-add.svelte-1qn0337:hover:not(:disabled) {
		background: var(--button-secondary-background-fill-hover);
	}

	.thumbnail-add.svelte-1qn0337:disabled {
		opacity: 0.5;
		cursor: not-allowed;
	}

	.thumbnail-add.svelte-1qn0337 svg {
		width: var(--size-5);
		height: var(--size-5);
	}

	.microphone-button.svelte-1qn0337,
	.icon-button.svelte-1qn0337 {
		width: var(--size-9);
		height: var(--size-9);
	}

	.microphone-button.svelte-1qn0337:hover:not(:disabled),
	.icon-button.svelte-1qn0337:hover:not(:disabled) {
		background: var(--button-secondary-background-fill);
	}

	.microphone-button.svelte-1qn0337:disabled,
	.icon-button.svelte-1qn0337:disabled {
		opacity: 0.5;
		cursor: not-allowed;
	}

	.microphone-button.svelte-1qn0337 svg,
	.icon-button.svelte-1qn0337 svg {
		width: var(--size-5);
		height: var(--size-5);
	}

	.submit-button.svelte-1qn0337,
	.stop-button.svelte-1qn0337 {
		background: var(--button-secondary-background-fill);
		cursor: pointer;
		display: flex;
		justify-content: center;
		align-items: center;
		flex-shrink: 0;
		width: var(--size-9);
		height: var(--size-9);
		border-radius: var(--radius-md);
		z-index: var(--layer-1);
	}

	.submit-button.svelte-1qn0337:hover:not(:disabled),
	.stop-button.svelte-1qn0337:hover:not(:disabled) {
		background: var(--button-secondary-background-fill-hover);
	}

	.submit-button.svelte-1qn0337:active:not(:disabled),
	.stop-button.svelte-1qn0337:active:not(:disabled) {
		box-shadow: var(--button-shadow-active);
	}

	.submit-button.svelte-1qn0337:disabled,
	.stop-button.svelte-1qn0337:disabled {
		cursor: not-allowed;
	}

	.submit-button.svelte-1qn0337 svg,
	.stop-button.svelte-1qn0337 svg {
		width: var(--size-5);
		height: var(--size-5);
	}

	.padded-button.svelte-1qn0337 {
		padding: 0 var(--spacing-lg);
		width: auto;
		border-radius: var(--radius-xl);
	}

	.loader.svelte-1qn0337 {
		display: flex;
		justify-content: center;
		align-items: center;
		position: relative;
		border: var(--size-1) solid var(--border-color-primary);
		border-top-color: var(--color-accent);
		border-radius: var(--radius-100);
		width: var(--size-5);
		height: var(--size-5);
		animation: svelte-1qn0337-spin 1s linear infinite;
		flex-shrink: 0;
	}

	@keyframes svelte-1qn0337-spin {
		to {
			transform: rotate(360deg);
		}
	}

	.recording-overlay.svelte-1qn0337 {
		position: absolute;
		top: 0;
		left: 0;
		right: 0;
		bottom: 0;
		background: var(--block-background-fill);
		border-radius: var(--radius-xl);
		display: flex;
		align-items: center;
		justify-content: center;
		z-index: var(--layer-5);
		padding: var(--spacing-lg);
		backdrop-filter: blur(8px);
		animation: svelte-1qn0337-fadeIn 0.2s var(--easing-standard);
	}

	@keyframes svelte-1qn0337-fadeIn {
		from {
			opacity: 0;
		}
		to {
			opacity: 1;
		}
	}

	.recording-content.svelte-1qn0337 {
		display: flex;
		align-items: center;
		gap: var(--spacing-lg);
		width: 100%;
		max-width: 700px;
	}

	.recording-content.svelte-1qn0337 .minimal-audio-recorder,
	.recording-content.svelte-1qn0337 .minimal-audio-player {
		flex: 1;
	}

	.action-buttons.svelte-1qn0337 {
		display: flex;
		align-items: center;
		gap: var(--spacing-sm);
		flex-shrink: 0;
	}

	.stop-button.svelte-1qn0337,
	.confirm-button.svelte-1qn0337,
	.cancel-button.svelte-1qn0337 {
		display: flex;
		align-items: center;
		justify-content: center;
		width: var(--size-9);
		height: var(--size-9);
		padding: 0;
		border-radius: var(--radius-md);
		cursor: pointer;
		flex-shrink: 0;
	}

	.stop-button.svelte-1qn0337 {
		background: var(--button-secondary-background-fill);
		border-color: var(--border-color-primary);
		color: var(--error-500);
	}

	.stop-button.svelte-1qn0337:hover {
		background: var(--button-secondary-background-fill-hover);
		color: var(--error-600);
	}

	.stop-button.svelte-1qn0337:active {
		transform: scale(0.95);
	}

	.confirm-button.svelte-1qn0337 {
		background: var(--button-primary-background-fill);
		border-color: var(--button-primary-border-color);
		color: white;
	}

	.confirm-button.svelte-1qn0337:hover {
		background: var(--button-primary-background-fill-hover);
		color: var(--button-primary-text-color-hover);
	}

	.confirm-button.svelte-1qn0337:active {
		transform: scale(0.95);
	}

	.cancel-button.svelte-1qn0337 {
		background: var(--button-secondary-background-fill);
		color: var(--body-text-color);
	}

	.cancel-button.svelte-1qn0337:hover {
		background: var(--button-secondary-background-fill-hover);
	}

	.stop-button.svelte-1qn0337 svg,
	.confirm-button.svelte-1qn0337 svg,
	.cancel-button.svelte-1qn0337 svg {
		width: var(--size-5);
		height: var(--size-5);
	}

	@media (max-width: 768px) {
		.input-wrapper.svelte-1qn0337 {
			padding: var(--spacing-xs);
		}

		.thumbnails.svelte-1qn0337 {
			padding: var(--spacing-xs) 0;
			margin-bottom: var(--spacing-md);
		}

		.thumbnail-small.svelte-1qn0337,
		.thumbnail-add.svelte-1qn0337 {
			width: var(--size-9);
			height: var(--size-9);
		}

		.thumbnail-item.svelte-1qn0337:active .delete-button:where(.svelte-1qn0337) {
			opacity: 1;
		}
	}

	.textarea-wrapper.svelte-1qn0337 {
		position: relative;
		flex-grow: 1;
	}

	.textarea-wrapper.svelte-1qn0337 textarea:where(.svelte-1qn0337) {
		width: 100%;
	}