
	.wrap.svelte-yb2gcx {
		display: flex;
		flex-wrap: wrap;
		gap: var(--checkbox-label-gap);
	}
	label.svelte-yb2gcx {
		display: flex;
		align-items: center;
		transition: var(--button-transition);
		cursor: pointer;
		box-shadow: var(--checkbox-label-shadow);
		border: var(--checkbox-label-border-width) solid
			var(--checkbox-label-border-color);
		border-radius: var(--checkbox-border-radius);
		background: var(--checkbox-label-background-fill);
		padding: var(--checkbox-label-padding);
		color: var(--checkbox-label-text-color);
		font-weight: var(--checkbox-label-text-weight);
		font-size: var(--checkbox-label-text-size);
		line-height: var(--line-md);
	}

	label.svelte-yb2gcx:hover {
		background: var(--checkbox-label-background-fill-hover);
	}
	label.svelte-yb2gcx:focus {
		background: var(--checkbox-label-background-fill-focus);
	}
	label.selected.svelte-yb2gcx {
		background: var(--checkbox-label-background-fill-selected);
		color: var(--checkbox-label-text-color-selected);
		border-color: var(--checkbox-label-border-color-selected);
	}

	label.svelte-yb2gcx > :where(.svelte-yb2gcx) + :where(.svelte-yb2gcx) {
		margin-left: var(--size-2);
	}

	input.svelte-yb2gcx {
		--ring-color: transparent;
		position: relative;
		box-shadow: var(--checkbox-shadow);
		border: var(--checkbox-border-width) solid var(--checkbox-border-color);
		border-radius: var(--checkbox-border-radius);
		background-color: var(--checkbox-background-color);
		line-height: var(--line-sm);
	}

	input.svelte-yb2gcx:checked,
	input.svelte-yb2gcx:checked:hover,
	input.svelte-yb2gcx:checked:focus {
		border-color: var(--checkbox-border-color-selected);
		background-image: var(--checkbox-check);
		background-color: var(--checkbox-background-color-selected);
	}

	input.svelte-yb2gcx:checked:focus {
		border-color: var(--checkbox-border-color-focus);
		background-image: var(--checkbox-check);
		background-color: var(--checkbox-background-color-selected);
	}

	input.svelte-yb2gcx:hover {
		border-color: var(--checkbox-border-color-hover);
		background-color: var(--checkbox-background-color-hover);
	}

	input.svelte-yb2gcx:not(:checked):focus {
		border-color: var(--checkbox-border-color-focus);
	}

	input[disabled].svelte-yb2gcx,
	.disabled.svelte-yb2gcx {
		cursor: not-allowed !important;
	}

	input[disabled].svelte-yb2gcx {
		opacity: 0.75;
	}

	input.svelte-yb2gcx:hover {
		cursor: pointer;
	}

	.select-all-container.svelte-yb2gcx {
		display: flex;
		align-items: center;
		gap: var(--size-2);
	}

	.select-all-label.svelte-yb2gcx {
		display: flex;
		align-items: center;
		cursor: pointer;
		margin: 0;
		padding: 0;
		background: none;
		border: none;
		box-shadow: none;
	}

	.select-all-checkbox.svelte-yb2gcx {
		--ring-color: transparent;
		position: relative;
		box-shadow: var(--checkbox-shadow);
		border: var(--checkbox-border-width) solid var(--checkbox-border-color);
		border-radius: var(--checkbox-border-radius);
		background-color: var(--checkbox-background-color);
		line-height: var(--line-sm);
		margin: 0;
	}

	.select-all-checkbox.svelte-yb2gcx:checked,
	.select-all-checkbox.svelte-yb2gcx:checked:hover,
	.select-all-checkbox.svelte-yb2gcx:checked:focus {
		border-color: var(--checkbox-border-color-selected);
		background-image: var(--checkbox-check);
		background-color: var(--checkbox-background-color-selected);
	}

	.select-all-checkbox.svelte-yb2gcx:indeterminate,
	.select-all-checkbox.svelte-yb2gcx:indeterminate:hover {
		border-color: var(--checkbox-border-color-selected);
		background-color: var(--checkbox-background-color-selected);
		position: relative;
	}

	.select-all-checkbox.svelte-yb2gcx:indeterminate::after {
		content: "";
		position: absolute;
		left: 50%;
		top: 50%;
		transform: translate(-50%, -50%);
		width: 60%;
		height: 2px;
		background-color: white;
	}

	.select-all-checkbox.svelte-yb2gcx:not(:indeterminate):not(:checked):hover {
		border-color: var(--checkbox-border-color-hover);
		background-color: var(--checkbox-background-color-hover);
		cursor: pointer;
	}

	.label-text.svelte-yb2gcx {
		margin: 0;
		cursor: pointer;
		background: none;
		border: none;
		padding: 0;
		font: inherit;
		color: inherit;
		text-align: left;
	}