
	.container.svelte-bs74gu img {
		width: 100%;
		height: 100%;
	}

	.container.selected.svelte-bs74gu {
		border-color: var(--border-color-accent);
	}
	.border.table.svelte-bs74gu {
		border: 2px solid var(--border-color-primary);
	}

	.container.table.svelte-bs74gu {
		margin: 0 auto;
		border-radius: var(--radius-lg);
		overflow: hidden;
		width: var(--size-20);
		height: var(--size-20);
		object-fit: cover;
	}

	.container.gallery.svelte-bs74gu {
		width: var(--size-20);
		max-width: var(--size-20);
		object-fit: cover;
	}