const _name = "Català";
const annotated_image = { "annotated_image": "Imatge Anotada" };
const audio = { "allow_recording_access": "Si us plau, permeteu l'accés al micròfon per gravar.", "audio": "Àudio", "record_from_microphone": "Gravar des del micròfon", "stop_recording": "Aturar la gravació", "no_device_support": "No s'ha pogut accedir als dispositius multimèdia. Comproveu que esteu executant en un origen segur (https) o localhost (o heu passat un certificat SSL vàlid a ssl_verify), i que heu permès l'accés del navegador al vostre dispositiu.", "stop": "Aturar", "resume": "Reprendre", "record": "Gravar", "no_microphone": "No s'ha trobat cap micròfon", "pause": "Pausa", "play": "Reproduir", "waiting": "Esperant", "drop_to_upload": "Arrossega un fitxer d'àudio aquí per pujar-lo" };
const blocks = { "connection_can_break": "En dispositius mòbils, la connexió es pot trencar si aquesta pestanya perd el focus o el dispositiu s'adorm, perdent la vostra posició a la cua.", "long_requests_queue": "Hi ha una llarga cua de sol·licituds pendents. Dupliqueu aquest Space per saltar-la.", "lost_connection": "S'ha perdut la connexió en deixar la pàgina. Tornant a la cua...", "waiting_for_inputs": "Esperant la finalització de la pujada dels fitxers, si us plau, torna a provar." };
const checkbox = { "checkbox": "Casella de selecció", "checkbox_group": "Grup de caselles" };
const code = { "code": "Codi" };
const color_picker = { "color_picker": "Selector de color" };
const common = { "built_with": "construït amb", "built_with_gradio": "Construït amb Gradio", "clear": "Neteja", "download": "Descarregar", "edit": "Editar", "empty": "Buit", "error": "Error", "hosted_on": "Allotjat a", "loading": "S'està carregant", "logo": "logotip", "or": "o", "remove": "Eliminar", "settings": "Configuració", "share": "Compartir", "submit": "Envia", "undo": "Desfer", "no_devices": "No s'han trobat dispositius", "language": "Idioma", "display_theme": "Tema de visualització", "pwa": "Aplicació web progressiva" };
const dataframe = { "incorrect_format": "Format incorrecte, només s'admeten fitxers CSV i TSV", "new_column": "Afegir columna", "new_row": "Nova fila", "add_row_above": "Afegir fila a dalt", "add_row_below": "Afegir fila a baix", "add_column_left": "Afegir columna a l'esquerra", "add_column_right": "Afegir columna a la dreta", "delete_row": "Esborrar fila", "delete_column": "Suprimeix la columna", "sort_column": "Ordena la columna", "sort_ascending": "Ordena ascendent", "sort_descending": "Ordena descendent", "drop_to_upload": "Arrossega fitxers CSV o TSV aquí per importar dades al dataframe", "clear_sort": "Neteja la classificació" };
const dropdown = { "dropdown": "Desplegable" };
const errors = { "build_error": "hi ha un error de compilació", "config_error": "hi ha un error de configuració", "contact_page_author": "Si us plau, contacteu amb l'autor de la pàgina per informar-lo.", "no_app_file": "no hi ha fitxer d'aplicació", "runtime_error": "hi ha un error d'execució", "space_not_working": `"L'Space no funciona perquè" {0}`, "space_paused": "l'space està en pausa", "use_via_api": "Utilitzar via API" };
const file = { "uploading": "Pujant..." };
const highlighted_text = { "highlighted_text": "Text ressaltat" };
const image = { "allow_webcam_access": "Si us plau, permeteu l'accés a la càmera web per gravar.", "brush_color": "Color del pinzell", "brush_radius": "Radi del pinzell", "image": "Imatge", "remove_image": "Eliminar imatge", "select_brush_color": "Seleccionar color del pinzell", "start_drawing": "Començar a dibuixar", "use_brush": "Utilitzar pinzell", "drop_to_upload": "Arrossega un fitxer d'imatge aquí per pujar-lo" };
const label = { "label": "Etiqueta" };
const login = { "enable_cookies": "Si esteu visitant un Space de HuggingFace en mode Incògnit, heu d'habilitar les cookies de tercers.", "incorrect_credentials": "Credencials incorrectes", "username": "nom d'usuari", "password": "contrasenya", "login": "Iniciar sessió" };
const number = { "number": "Número" };
const plot = { "plot": "Gràfic" };
const radio = { "radio": "Ràdio" };
const slider = { "slider": "Control lliscant" };
const upload_text = { "click_to_upload": "Feu clic per pujar", "drop_audio": "Deixeu anar l'àudio aquí", "drop_csv": "Deixeu anar el CSV aquí", "drop_file": "Deixeu anar el fitxer aquí", "drop_image": "Deixeu anar la imatge aquí", "drop_video": "Deixeu anar el vídeo aquí", "drop_gallery": "Deixeu anar els mitjans aquí", "paste_clipboard": "Enganxar del porta-retalls" };
const video = { "drop_to_upload": "Arrossega un fitxer de vídeo aquí per pujar-lo" };
const chatbot = { "edit": "Editar", "retry": "Tornar a provar", "undo": "Desfer", "submit": "Enviar", "cancel": "Cancel·lar", "like": "M'agrada", "dislike": "No m'agrada", "clear": "Netejar xat" };
const ca = {
  _name,
  "3D_model": { "3d_model": "Model 3D", "drop_to_upload": "Arrossega un model 3D (.obj, .glb, .stl, .gltf, .splat o .ply) aquí per pujar-lo." },
  annotated_image,
  audio,
  blocks,
  checkbox,
  code,
  color_picker,
  common,
  dataframe,
  dropdown,
  errors,
  file,
  highlighted_text,
  image,
  label,
  login,
  number,
  plot,
  radio,
  slider,
  upload_text,
  video,
  chatbot
};

export { _name, annotated_image, audio, blocks, chatbot, checkbox, code, color_picker, common, dataframe, ca as default, dropdown, errors, file, highlighted_text, image, label, login, number, plot, radio, slider, upload_text, video };
//# sourceMappingURL=ca-xGgXl-3Z.js.map
