
	.json-node.svelte-1olemhd {
		font-family: var(--font-mono);
		--text-color: #d18770;
		--key-color: var(--text-color);
		--string-color: #ce9178;
		--number-color: #719fad;

		--bracket-color: #5d8585;
		--square-bracket-color: #be6069;
		--punctuation-color: #8fbcbb;
		--line-number-color: #6a737d;
		--separator-color: var(--line-number-color);
	}
	.json-node.dark-mode.svelte-1olemhd {
		--bracket-color: #7eb4b3;
		--number-color: #638d9a;
	}
	.json-node.root.svelte-1olemhd {
		position: relative;
		padding-left: var(--size-14);
	}
	.json-node.root.svelte-1olemhd::before {
		content: "";
		position: absolute;
		top: 0;
		bottom: 0;
		left: var(--size-11);
		width: 1px;
		background-color: var(--separator-color);
	}
	.line.svelte-1olemhd {
		display: flex;
		align-items: flex-start;
		padding: 0;
		margin: 0;
		line-height: var(--line-md);
	}
	.line-number.svelte-1olemhd {
		position: absolute;
		left: 0;
		width: calc(var(--size-7));
		text-align: right;
		color: var(--line-number-color);
		user-select: none;
		text-overflow: ellipsis;
		text-overflow: ellipsis;
		direction: rtl;
		overflow: hidden;
	}
	.content.svelte-1olemhd {
		flex: 1;
		display: flex;
		align-items: center;
		padding-left: calc(var(--depth) * var(--size-2));
		flex-wrap: wrap;
	}
	.children.svelte-1olemhd {
		padding-left: var(--size-4);
	}
	.children.hidden.svelte-1olemhd {
		display: none;
	}
	.key.svelte-1olemhd {
		color: var(--key-color);
	}
	.string.svelte-1olemhd {
		color: var(--string-color);
	}
	.number.svelte-1olemhd {
		color: var(--number-color);
	}
	.bool.svelte-1olemhd {
		color: var(--text-color);
	}
	.null.svelte-1olemhd {
		color: var(--text-color);
	}
	.value.svelte-1olemhd {
		margin-left: var(--spacing-md);
	}
	.punctuation.svelte-1olemhd {
		color: var(--punctuation-color);
	}
	.bracket.svelte-1olemhd {
		margin-left: var(--spacing-sm);
		color: var(--bracket-color);
	}
	.square-bracket.svelte-1olemhd {
		margin-left: var(--spacing-sm);
		color: var(--square-bracket-color);
	}
	.toggle.svelte-1olemhd,
	.preview.svelte-1olemhd {
		background: none;
		border: none;
		color: inherit;
		cursor: pointer;
		padding: 0;
		margin: 0;
	}
	.toggle.svelte-1olemhd {
		user-select: none;
		margin-right: var(--spacing-md);
	}
	.preview.svelte-1olemhd {
		margin: 0 var(--spacing-sm) 0 var(--spacing-lg);
	}
	.preview.svelte-1olemhd:hover {
		text-decoration: underline;
	}

	[data-pseudo-content]::before {
		content: attr(data-pseudo-content);
	}
	.copied svg {
		animation: svelte-1lc38wd-fade ease 300ms;
		animation-fill-mode: forwards;
	}

	@keyframes svelte-1lc38wd-fade {
		0% {
			opacity: 0;
		}
		100% {
			opacity: 1;
		}
	}

	.json-holder.svelte-1lc38wd {
		padding: var(--size-2);
		overflow-y: auto;
	}

	.empty-wrapper.svelte-1lc38wd {
		min-height: calc(var(--size-32) - 20px);
		height: 100%;
	}