const _name = "עברית";
const annotated_image = { "annotated_image": "תמונה מוערת" };
const audio = { "allow_recording_access": "אנא אפשר/י גישה למיקרופון להקלטה.", "audio": "שמע", "record_from_microphone": "הקלט ממיקרופון", "stop_recording": "עצור הקלטה", "no_device_support": "לא ניתן לגשת להתקני מדיה. וודא שאתה מריץ ממקור מאובטח (https) או localhost (או שהעברת אישור SSL תקף ל-ssl_verify), ושאישרת לדפדפן גישה למכשיר שלך.", "stop": "עצור", "resume": "המשך", "record": "הקלט", "no_microphone": "לא נמצא מיקרופון", "pause": "השהה", "play": "נגן", "waiting": "ממתין", "drop_to_upload": "הטילו קובץ אודיו כאן כדי להעלות" };
const blocks = { "connection_can_break": "בנייד, החיבור עלול להתנתק אם כרטיסייה זו מאבדת מיקוד או המכשיר נכנס למצב שינה, מה שיגרום לאיבוד מקומך בתור.", "long_requests_queue": "יש תור ארוך של בקשות ממתינות. שכפל Space זה כדי לדלג על התור.", "lost_connection": "החיבור אבד בגלל עזיבת העמוד. חוזר לתור...", "waiting_for_inputs": "מחכים לסיום העלאה של הקבצים, אנא נסה שוב." };
const checkbox = { "checkbox": "תיבת סימון", "checkbox_group": "קבוצת תיבות סימון" };
const code = { "code": "קוד" };
const color_picker = { "color_picker": "בוחר צבעים" };
const common = { "built_with": "נבנה עם", "built_with_gradio": "נבנה עם Gradio", "clear": "נקה", "download": "הורד", "edit": "ערוך", "empty": "ריק", "error": "שגיאה", "hosted_on": "מאוחסן ב", "loading": "טוען", "logo": "לוגו", "or": "או", "remove": "הסר", "settings": "הגדרות", "share": "שתף", "submit": "שלח", "undo": "בטל", "no_devices": "לא נמצאו התקנים", "language": "שפה", "display_theme": "ערכת נושא", "pwa": "יישום ווב מתקדם" };
const dataframe = { "incorrect_format": "פורמט שגוי, רק קבצי CSV ו-TSV נתמכים", "new_column": "הוסף עמודה", "new_row": "שורה חדשה", "add_row_above": "הוסף שורה מעל", "add_row_below": "הוסף שורה מתחת", "add_column_left": "הוסף עמודה משמאל", "add_column_right": "הוסף עמודה מימין", "delete_row": "מחק שורה", "delete_column": "מחק עמודה", "sort_column": "מיין עמודה", "sort_ascending": "מיין בסדר עולה", "sort_descending": "מיין בסדר יורד", "drop_to_upload": "הטילו קבצי CSV או TSV כאן כדי לייבא נתונים לתוך dataframe", "clear_sort": "נקה סדר" };
const dropdown = { "dropdown": "תפריט נפתח" };
const errors = { "build_error": "יש שגיאת בנייה", "config_error": "יש שגיאת תצורה", "contact_page_author": "אנא צור קשר עם מחבר העמוד כדי ליידע אותו.", "no_app_file": "אין קובץ יישום", "runtime_error": "יש שגיאת זמן ריצה", "space_not_working": '"ה-Space לא עובד כי" {0}', "space_paused": "ה-Space מושהה", "use_via_api": "השתמש דרך API" };
const file = { "uploading": "מעלה..." };
const highlighted_text = { "highlighted_text": "טקסט מודגש" };
const image = { "allow_webcam_access": "אנא אפשר גישה למצלמת האינטרנט להקלטה.", "brush_color": "צבע מברשת", "brush_radius": "גודל מברשת", "image": "תמונה", "remove_image": "הסר תמונה", "select_brush_color": "בחר צבע מברשת", "start_drawing": "התחל לצייר", "use_brush": "השתמש במברשת", "drop_to_upload": "הטילו קובץ תמונה כאן כדי להעלות" };
const label = { "label": "תווית" };
const login = { "enable_cookies": "אם אתה מבקר ב-Space של HuggingFace במצב גלישה בסתר, עליך לאפשר קובצי cookie של צד שלישי.", "incorrect_credentials": "פרטי התחברות שגויים", "username": "שם משתמש", "password": "סיסמה", "login": "התחבר" };
const number = { "number": "מספר" };
const plot = { "plot": "תרשים" };
const radio = { "radio": "כפתור רדיו" };
const slider = { "slider": "מחוון" };
const upload_text = { "click_to_upload": "לחץ להעלאה", "drop_audio": "שחרר קובץ שמע כאן", "drop_csv": "שחרר קובץ CSV כאן", "drop_file": "שחרר קובץ כאן", "drop_image": "שחרר תמונה כאן", "drop_video": "שחרר וידאו כאן", "drop_gallery": "שחרר מדיה כאן", "paste_clipboard": "הדבק מהלוח" };
const video = { "drop_to_upload": "הטילו קובץ וידאו כאן כדי להעלות" };
const chatbot = { "edit": "עריכה", "retry": "נסה שוב", "undo": "בטל", "submit": "שלח", "cancel": "ביטול", "like": "אהבתי", "dislike": "לא אהבתי", "clear": "נקה שיחה" };
const he = {
  _name,
  "3D_model": { "3d_model": "מודל תלת מימד", "drop_to_upload": "הטילו קובץ מודל 3D (.obj, .glb, .stl, .gltf, .splat או .ply) כאן כדי להעלות" },
  annotated_image,
  audio,
  blocks,
  checkbox,
  code,
  color_picker,
  common,
  dataframe,
  dropdown,
  errors,
  file,
  highlighted_text,
  image,
  label,
  login,
  number,
  plot,
  radio,
  slider,
  upload_text,
  video,
  chatbot
};

export { _name, annotated_image, audio, blocks, chatbot, checkbox, code, color_picker, common, dataframe, he as default, dropdown, errors, file, highlighted_text, image, label, login, number, plot, radio, slider, upload_text, video };
//# sourceMappingURL=he-DklLcpNM.js.map
