const _name = "हिंदी";
const annotated_image = { "annotated_image": "एनोटेट की गई छवि" };
const audio = { "allow_recording_access": "कृपया रिकॉर्डिंग के लिए माइक्रोफ़ोन एक्सेस की अनुमति दें।", "audio": "ऑडियो", "record_from_microphone": "माइक्रोफ़ोन से रिकॉर्ड करें", "stop_recording": "रिकॉर्डिंग रोकें", "no_device_support": "मीडिया डिवाइस तक पहुंच नहीं हो सकी। सुनिश्चित करें कि आप एक सुरक्षित स्रोत (https) या localhost पर चल रहे हैं (या ssl_verify को एक वैध SSL प्रमाणपत्र दिया है), और आपने अपने ब्राउज़र को अपने डिवाइस तक पहुंच की अनुमति दी है।", "stop": "रोकें", "resume": "जारी रखें", "record": "रिकॉर्ड", "no_microphone": "कोई माइक्रोफ़ोन नहीं मिला", "pause": "रोकें", "play": "चलाएं", "waiting": "प्रतीक्षा कर रहा है", "drop_to_upload": "यहाँ एक ऑडियो फाइल डालें अपलोड करने के लिए" };
const blocks = { "connection_can_break": "मोबाइल पर, यदि यह टैब फोकस खो देता है या डिवाइस स्लीप मोड में चला जाता है, तो कनेक्शन टूट सकता है, जिससे कतार में आपका स्थान खो जाएगा।", "long_requests_queue": "लंबित अनुरोधों की एक लंबी कतार है। इसे छोड़ने के लिए इस Space को डुप्लिकेट करें।", "lost_connection": "पेज छोड़ने के कारण कनेक्शन टूट गया। कतार में वापस जा रहा है...", "waiting_for_inputs": "फाइलें अपलोड होने का इंतजार कर रहे हैं, कृपया पुन: प्रयास करें।" };
const checkbox = { "checkbox": "चेकबॉक्स", "checkbox_group": "चेकबॉक्स समूह" };
const code = { "code": "कोड" };
const color_picker = { "color_picker": "रंग चयनकर्ता" };
const common = { "built_with": "के साथ बनाया गया", "built_with_gradio": "Gradio के साथ बनाया गया", "clear": "साफ़ करें", "download": "डाउनलोड", "edit": "संपादित करें", "empty": "खाली", "error": "त्रुटि", "hosted_on": "पर होस्ट किया गया", "loading": "लोड हो रहा है", "logo": "लोगो", "or": "या", "remove": "हटाएं", "settings": "सेटिंग्स", "share": "साझा करें", "submit": "सबमिट करें", "undo": "पूर्ववत करें", "no_devices": "कोई डिवाइस नहीं मिला", "language": "भाषा", "display_theme": "प्रदर्शन थीम", "pwa": "प्रोग्रेसिव वेब ऐप" };
const dataframe = { "incorrect_format": "गलत प्रारूप, केवल CSV और TSV फ़ाइलें समर्थित हैं", "new_column": "कॉलम जोड़ें", "new_row": "नई पंक्ति", "add_row_above": "ऊपर पंक्ति जोड़ें", "add_row_below": "नीचे पंक्ति जोड़ें", "add_column_left": "बाएं कॉलम जोड़ें", "add_column_right": "दाएं कॉलम जोड़ें", "delete_row": "पंक्ति हटाएं", "delete_column": "कॉलम हटाएं", "sort_column": "कॉलम को क्रमबद्ध करें", "sort_ascending": "आरोही क्रम में क्रमबद्ध करें", "sort_descending": "अवरोही क्रम में क्रमबद्ध करें", "drop_to_upload": "यहाँ CSV या TSV फाइलें ड्रॉप करें ताकि डेटा डेटाफ़्रेम में आयात किया जा सके", "clear_sort": "क्रमबद्धता हटाएं" };
const dropdown = { "dropdown": "ड्रॉपडाउन" };
const errors = { "build_error": "एक बिल्ड त्रुटि है", "config_error": "एक कॉन्फ़िगरेशन त्रुटि है", "contact_page_author": "कृपया पेज के लेखक को सूचित करने के लिए संपर्क करें।", "no_app_file": "कोई ऐप फ़ाइल नहीं है", "runtime_error": "एक रनटाइम त्रुटि है", "space_not_working": '"Space काम नहीं कर रहा है क्योंकि" {0}', "space_paused": "Space रोका गया है", "use_via_api": "API के माध्यम से उपयोग करें" };
const file = { "uploading": "अपलोड हो रहा है..." };
const highlighted_text = { "highlighted_text": "हाइलाइट किया गया टेक्स्ट" };
const image = { "allow_webcam_access": "कृपया रिकॉर्डिंग के लिए वेबकैम एक्सेस की अनुमति दें।", "brush_color": "ब्रश का रंग", "brush_radius": "ब्रश का आकार", "image": "छवि", "remove_image": "छवि हटाएं", "select_brush_color": "ब्रश का रंग चुनें", "start_drawing": "चित्रकारी शुरू करें", "use_brush": "ब्रश का उपयोग करें", "drop_to_upload": "यहाँ एक छवि फाइल डालें अपलोड करने के लिए" };
const label = { "label": "लेबल" };
const login = { "enable_cookies": "यदि आप इनकॉग्निटो मोड में HuggingFace Space का दौरा कर रहे हैं, तो आपको थर्ड-पार्टी कुकीज़ को सक्षम करना होगा।", "incorrect_credentials": "गलत क्रेडेंशियल्स", "username": "उपयोगकर्ता नाम", "password": "पासवर्ड", "login": "लॉग इन करें" };
const number = { "number": "संख्या" };
const plot = { "plot": "प्लॉट" };
const radio = { "radio": "रेडियो बटन" };
const slider = { "slider": "स्लाइडर" };
const upload_text = { "click_to_upload": "अपलोड करने के लिए क्लिक करें", "drop_audio": "ऑडियो यहाँ छोड़ें", "drop_csv": "CSV फाइल यहाँ छोड़ें", "drop_file": "फ़ाइल यहाँ छोड़ें", "drop_image": "छवि यहाँ छोड़ें", "drop_video": "वीडियो यहाँ छोड़ें", "drop_gallery": "मीडिया यहाँ छोड़ें", "paste_clipboard": "क्लिपबोर्ड से पेस्ट करें" };
const video = { "drop_to_upload": "यहाँ एक वीडियो फाइल डालें अपलोड करने के लिए" };
const chatbot = { "edit": "संपादित करें", "retry": "पुनः प्रयास करें", "undo": "वापस लें", "submit": "भेजें", "cancel": "रद्द करें", "like": "पसंद", "dislike": "नापसंद", "clear": "चैट साफ़ करें" };
const hi = {
  _name,
  "3D_model": { "3d_model": "3D मॉडल", "drop_to_upload": "यहाँ 3D मॉडल (.obj, .glb, .stl, .gltf, .splat, या .ply) फ़ाइल ड्रॉप करें अपलोड करने के लिए" },
  annotated_image,
  audio,
  blocks,
  checkbox,
  code,
  color_picker,
  common,
  dataframe,
  dropdown,
  errors,
  file,
  highlighted_text,
  image,
  label,
  login,
  number,
  plot,
  radio,
  slider,
  upload_text,
  video,
  chatbot
};

export { _name, annotated_image, audio, blocks, chatbot, checkbox, code, color_picker, common, dataframe, hi as default, dropdown, errors, file, highlighted_text, image, label, login, number, plot, radio, slider, upload_text, video };
//# sourceMappingURL=hi-C4p28L1P.js.map
