
	.wrap.svelte-pndh99 {
		display: flex;
		flex-direction: column;
		flex-grow: 1;
		margin: 0;
		padding: 0;
		height: 100%;
	}
	.codemirror-wrapper.svelte-pndh99 {
		flex-grow: 1;
		overflow: auto;
	}

	.cm-editor {
		height: 100%;
	}

	/* Dunno why this doesn't work through the theme API -- don't remove*/
	.cm-selectionBackground {
		background-color: #b9d2ff30 !important;
	}

	.cm-focused {
		outline: none !important;
	}