
	.load-wrap.svelte-mctcyk {
		display: flex;
		justify-content: center;
		align-items: center;
		height: 100%;
	}
	.loader.svelte-mctcyk {
		display: flex;
		position: relative;
		background-color: var(--border-color-accent-subdued);
		animation: svelte-mctcyk-shadowPulse 2s linear infinite;
		box-shadow:
			-24px 0 var(--border-color-accent-subdued),
			24px 0 var(--border-color-accent-subdued);
		margin: var(--spacing-md);
		border-radius: 50%;
		width: 10px;
		height: 10px;
		scale: 0.5;
	}

	@keyframes svelte-mctcyk-shadowPulse {
		33% {
			box-shadow:
				-24px 0 var(--border-color-accent-subdued),
				24px 0 #fff;
			background: #fff;
		}
		66% {
			box-shadow:
				-24px 0 #fff,
				24px 0 #fff;
			background: var(--border-color-accent-subdued);
		}
		100% {
			box-shadow:
				-24px 0 #fff,
				24px 0 var(--border-color-accent-subdued);
			background: #fff;
		}
	}

	.container.svelte-mctcyk {
		display: flex;
		flex-direction: column;
		align-items: center;
		justify-content: center;
		margin: var(--spacing-lg) var(--spacing-lg) 0 var(--spacing-lg);
	}

	#timeline.svelte-mctcyk {
		display: flex;
		height: var(--size-10);
		flex: 1;
		position: relative;
	}

	img.svelte-mctcyk {
		flex: 1 1 auto;
		min-width: 0;
		object-fit: cover;
		height: var(--size-12);
		border: 1px solid var(--block-border-color);
		user-select: none;
		z-index: 1;
	}

	.handle.svelte-mctcyk {
		width: 3px;
		background-color: var(--color-accent);
		cursor: ew-resize;
		height: var(--size-12);
		z-index: 3;
		position: absolute;
	}

	.opaque-layer.svelte-mctcyk {
		background-color: rgba(230, 103, 40, 0.25);
		border: 1px solid var(--color-accent);
		height: var(--size-12);
		position: absolute;
		z-index: 2;
	}
	.container.svelte-1orxdv {
		width: 100%;
	}
	time.svelte-1orxdv {
		color: var(--color-accent);
		font-weight: bold;
		padding-left: var(--spacing-xs);
	}

	.timeline-wrapper.svelte-1orxdv {
		display: flex;
		align-items: center;
		justify-content: center;
		width: 100%;
	}

	.text-button.svelte-1orxdv {
		border: 1px solid var(--neutral-400);
		border-radius: var(--radius-sm);
		font-weight: 300;
		font-size: var(--size-3);
		text-align: center;
		color: var(--neutral-400);
		height: var(--size-5);
		font-weight: bold;
		padding: 0 5px;
		margin-left: 5px;
	}

	.text-button.svelte-1orxdv:hover,
	.text-button.svelte-1orxdv:focus {
		color: var(--color-accent);
		border-color: var(--color-accent);
	}

	.controls.svelte-1orxdv {
		display: flex;
		justify-content: space-between;
		align-items: center;
		margin: var(--spacing-lg);
		overflow: hidden;
	}

	.edit-buttons.svelte-1orxdv {
		display: flex;
		gap: var(--spacing-sm);
	}

	@media (max-width: 320px) {
		.controls.svelte-1orxdv {
			flex-direction: column;
			align-items: flex-start;
		}

		.edit-buttons.svelte-1orxdv {
			margin-top: var(--spacing-sm);
		}

		.controls.svelte-1orxdv :where(.svelte-1orxdv) {
			margin: var(--spacing-sm);
		}

		.controls.svelte-1orxdv .text-button:where(.svelte-1orxdv) {
			margin-left: 0;
		}
	}

	.container.svelte-1orxdv {
		display: flex;
		flex-direction: column;
	}

	.hidden.svelte-1orxdv {
		display: none;
	}
	.volume-slider.svelte-h4x5cd {
		-webkit-appearance: none;
		appearance: none;
		width: var(--size-20);
		accent-color: var(--color-accent);
		height: 4px;
		cursor: pointer;
		outline: none;
		border-radius: 15px;
		background-color: rgba(255, 255, 255, 0.3);
		margin-left: var(--spacing-sm);
	}

	input[type="range"].svelte-h4x5cd::-webkit-slider-thumb {
		-webkit-appearance: none;
		appearance: none;
		height: 15px;
		width: 15px;
		background-color: white;
		border-radius: 50%;
		border: none;
		transition: 0.2s ease-in-out;
	}

	input[type="range"].svelte-h4x5cd::-moz-range-thumb {
		height: 15px;
		width: 15px;
		background-color: white;
		border-radius: 50%;
		border: none;
		transition: 0.2s ease-in-out;
	}
	span.svelte-1k28h7x {
		text-shadow: 0 0 8px rgba(0, 0, 0, 0.5);
	}

	progress.svelte-1k28h7x {
		margin-right: var(--size-3);
		border-radius: var(--radius-sm);
		width: var(--size-full);
		height: var(--size-2);
	}

	progress.svelte-1k28h7x::-webkit-progress-bar {
		border-radius: 2px;
		background-color: rgba(255, 255, 255, 0.2);
		overflow: hidden;
	}

	progress.svelte-1k28h7x::-webkit-progress-value {
		background-color: rgba(255, 255, 255, 0.9);
	}

	.mirror.svelte-1k28h7x {
		transform: scaleX(-1);
	}

	.mirror-wrap.svelte-1k28h7x {
		position: relative;
		height: 100%;
		width: 100%;
	}

	.controls.svelte-1k28h7x {
		position: absolute;
		bottom: 0;
		opacity: 0;
		transition: 500ms;
		margin: var(--size-2);
		border-radius: var(--radius-md);
		background: var(--color-grey-800);
		padding: var(--size-2) var(--size-1);
		width: calc(100% - 0.375rem * 2);
		width: calc(100% - var(--size-2) * 2);
		z-index: 10;
	}
	.wrap.svelte-1k28h7x:hover .controls:where(.svelte-1k28h7x) {
		opacity: 1;
	}
	:fullscreen .controls.svelte-1k28h7x {
		display: none;
	}

	.inner.svelte-1k28h7x {
		display: flex;
		justify-content: space-between;
		align-items: center;
		padding-right: var(--size-2);
		padding-left: var(--size-2);
		width: var(--size-full);
		height: var(--size-full);
	}

	.icon.svelte-1k28h7x {
		display: flex;
		justify-content: center;
		cursor: pointer;
		width: var(--size-6);
		color: white;
	}

	.volume-control-wrapper.svelte-1k28h7x {
		position: relative;
		display: flex;
		align-items: center;
		margin-right: var(--spacing-md);
	}

	.volume-button.svelte-1k28h7x {
		display: flex;
		justify-content: center;
		align-items: center;
		cursor: pointer;
		width: var(--size-6);
		color: white;
		border: none;
		background: none;
		padding: 0;
	}

	.time.svelte-1k28h7x {
		flex-shrink: 0;
		margin-right: var(--size-3);
		margin-left: var(--size-3);
		color: white;
		font-size: var(--text-sm);
		font-family: var(--font-mono);
	}
	.wrap.svelte-1k28h7x {
		position: relative;
		background-color: var(--background-fill-secondary);
		height: var(--size-full);
		width: var(--size-full);
		border-radius: var(--radius-xl);
	}
	.wrap.svelte-1k28h7x video {
		height: var(--size-full);
		width: var(--size-full);
	}