import './async-D55cHugf.js';
import { o as onDestroy } from './index-server-BzRj6e_1.js';
import './2-BYQShRaz.js';
import { G as Gradio } from './utils.svelte-DcXWObof.js';
import './context-DF4-UEpk.js';
import './index5-BZVOFaHm.js';
import './dev-fallback-B-RpELjM.js';
import './index-Cg-Pg6j3.js';

function Index($$renderer, $$props) {
  $$renderer.component(($$renderer2) => {
    const { $$slots, $$events, ...props } = $$props;
    new Gradio(props);
    onDestroy(() => {
    });
  });
}

export { Index as default };
//# sourceMappingURL=Index19-tUCsxMsE.js.map
