/**
 * @param {string} value
 */
function html(value) {
	var html = String(value ?? '');
	var open = '<!---->';
	return open + html + '<!---->';
}

export { html as h };
//# sourceMappingURL=html-CfyvkLET.js.map
