import './i18n-CGlVUOvE.js';
import { a as append, f as from_svg } from './index-Bq2njFOY.js';

var root = from_svg(`<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-file"><path d="M13 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V9z"></path><polyline points="13 2 13 9 20 9"></polyline></svg>`);

function File($$anchor) {
	var svg = root();

	append($$anchor, svg);
}

export { File as F };
//# sourceMappingURL=File-BiXBtg1a.js.map
