const __viteBrowserExternal = {};

const __viteBrowserExternal$1 = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
	__proto__: null,
	default: __viteBrowserExternal
}, Symbol.toStringTag, { value: 'Module' }));

export { __viteBrowserExternal$1 as _ };
//# sourceMappingURL=__vite-browser-external-CVaeKfQx.js.map
