import './async-D55cHugf.js';
import { e as escape_html } from './escaping-CBnpiEl5.js';

function Example($$renderer, $$props) {
  let { value } = $$props;
  $$renderer.push(`<!---->${escape_html(value || "")}`);
}

export { Example as default };
//# sourceMappingURL=Example3-CxHLke4-.js.map
