const index = 1;
let component_cache;
const component = async () => component_cache ??= (await import('./error.svelte-B665VEDR.js')).default;
const imports = ["_app/immutable/nodes/1.2vh1N-gW.js","_app/immutable/chunks/Bwz6a6nB.js","_app/immutable/chunks/D_0idP7x.js","_app/immutable/chunks/BHyOYhsu.js","_app/immutable/chunks/Cg5A2mhh.js","_app/immutable/chunks/WFX5e7SJ.js","_app/immutable/chunks/Dn6kO8JW.js","_app/immutable/chunks/C0L-Xv56.js"];
const stylesheets = [];
const fonts = [];

export { component, fonts, imports, index, stylesheets };
//# sourceMappingURL=1-CFR9voR5.js.map
