/* PrismJS 1.20.0
https://prismjs.com/download.html#themes=prism&languages=python */
/**
 * prism.js default theme for JavaScript, CSS and HTML
 * Based on dabblet (http://dabblet.com)
 * @author Lea Verou
 */

code[class*="language-"],
pre[class*="language-"],
pre.gradio-code,
pre.gradio-code code {
	word-wrap: normal;
	color: #171717;
	font-size: 1em;
	line-height: 1.5;
	font-family: Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace;

	-webkit-hyphens: none;
	-moz-hyphens: none;
	-ms-hyphens: none;
	hyphens: none;
	text-align: left;
	text-shadow: 0 1px white;
	white-space: pre;
	word-break: normal;
	word-spacing: normal;

	-moz-tab-size: 4;
	-o-tab-size: 4;
	tab-size: 4;
	font-size: 0.9em;
}

pre[class*="language-"]::-moz-selection,
pre[class*="language-"] ::-moz-selection,
code[class*="language-"]::-moz-selection,
code[class*="language-"] ::-moz-selection {
	background: #b3d4fc;
	text-shadow: none;
}

pre[class*="language-"]::selection,
pre[class*="language-"] ::selection,
code[class*="language-"]::selection,
code[class*="language-"] ::selection {
	background: #b3d4fc;
	text-shadow: none;
}

@media print {
	code[class*="language-"],
	pre[class*="language-"] {
		text-shadow: none;
	}
}

/* Code blocks */
pre[class*="language-"],
pre.gradio-code {
	margin: 0;
	padding: 0;
	overflow: auto;
}

:not(pre) > code[class*="language-"],
pre[class*="language-"],
pre.gradio-code {
	background: rgb(249, 250, 251);
}

.dark :not(pre) > code[class*="language-"],
.dark pre[class*="language-"],
.dark pre.gradio-code {
	background: rgb(38, 38, 38);
}

.dark code[class*="language-"],
.dark pre[class*="language-"],
.dark pre.gradio-code,
.dark pre.gradio-code code {
	text-shadow: none;
	color: #e6edf3;
}

.prose code[class*="language-"],
.prose pre[class*="language-"],
.prose pre.gradio-code,
.prose pre.gradio-code code {
	font-size: 0.9em;
}

/* Inline code */
:not(pre) > code[class*="language-"] {
	border-radius: 0.3em;
	padding: 0.1em;
	white-space: normal;
}

.token.comment,
.token.prolog,
.token.doctype,
.token.cdata {
	color: slategray;
}

.token.punctuation {
	color: #999;
}

.token.namespace {
	color: #6f42c1;
}

.token.function-call {
	color: #dd4a68;
}

.token.property,
.token.tag,
.token.boolean,
.token.number,
.token.constant,
.token.symbol,
.token.deleted {
	color: #905;
}

.token.selector,
.token.attr-name,
.token.string,
.token.char,
.token.builtin,
.token.inserted {
	color: #690;
}

.token.operator,
.token.entity,
.token.url,
.language-css .token.string,
.style .token.string {
	background: hsla(0, 0%, 100%, 0.5);
	color: #9a6e3a;
}

.token.atrule,
.token.attr-value,
.token.keyword {
	color: #07a;
}

.token.function,
.token.class-name {
	color: #dd4a68;
}

.token.regex,
.token.important,
.token.variable {
	color: #e90;
}

.token.annotation,
.token.decorator {
	color: #9a6e3a;
}

.token.keyword-argument {
	color: #e36209;
	font-style: italic;
}

.token.important,
.token.bold {
	font-weight: bold;
}
.token.italic {
	font-style: italic;
}

.token.entity {
	cursor: help;
}

/* Dark mode syntax highlighting */
.dark .token.comment,
.dark .token.prolog,
.dark .token.doctype,
.dark .token.cdata {
	color: #8b949e;
}

.dark .token.punctuation {
	color: #c9d1d9;
}

.dark .token.property,
.dark .token.tag,
.dark .token.boolean,
.dark .token.number,
.dark .token.constant,
.dark .token.symbol,
.dark .token.deleted {
	color: #ff7b72;
}

.dark .token.selector,
.dark .token.attr-name,
.dark .token.string,
.dark .token.char,
.dark .token.builtin,
.dark .token.inserted {
	color: #a5d6ff;
}

.dark .token.operator,
.dark .token.entity,
.dark .token.url,
.dark .language-css .token.string,
.dark .style .token.string {
	background: transparent;
	color: #ffa657;
}

.dark .token.atrule,
.dark .token.attr-value,
.dark .token.keyword {
	color: #ff7b72;
}

.dark .token.function,
.dark .token.class-name {
	color: #d2a8ff;
}

.dark .token.regex,
.dark .token.important,
.dark .token.variable {
	color: #ffa657;
}

.dark .token.annotation,
.dark .token.decorator {
	color: #ffa657;
}

.dark .token.namespace {
	color: #79c0ff;
}

.dark .token.function-call {
	color: #d2a8ff;
}

.dark .token.keyword-argument {
	color: #ffa657;
	font-style: italic;
}
