
	.s--slider.svelte-1io85vl {
		display: flex;
		align-items: center;
	}

	.s--slider.svelte-1io85vl button:where(.svelte-1io85vl) {
		width: 3em;
		height: 1.6em;
		position: relative;
		margin: 0 0.5em 0 0;
		background: var(--button-secondary-background-fill);
		border: none;
	}

	.s--slider.svelte-1io85vl button[disabled]:where(.svelte-1io85vl) {
		cursor: not-allowed;
	}

	.s--slider.svelte-1io85vl button:where(.svelte-1io85vl)::before {
		content: "";
		position: absolute;
		width: 1.3em;
		height: 1.3em;
		background: #fff;
		top: 0.13em;
		right: 1.5em;
		transition: transform 0.3s;
	}

	.s--slider.svelte-1io85vl button[aria-checked="true"]:where(.svelte-1io85vl) {
		background-color: var(--color-accent);
	}

	.s--slider.svelte-1io85vl button[aria-checked="true"]:where(.svelte-1io85vl)::before {
		transform: translateX(1.3em);
		transition: transform 0.3s;
	}

	.s--slider.svelte-1io85vl button:where(.svelte-1io85vl):focus {
		box-shadow: 0 0px 0px 1px var(--color-accent);
	}

	/* Slider Design Option */
	.s--slider.svelte-1io85vl button:where(.svelte-1io85vl) {
		border-radius: 1.5em;
	}

	.s--slider.svelte-1io85vl button:where(.svelte-1io85vl)::before {
		border-radius: 100%;
	}

	.s--slider.svelte-1io85vl button:where(.svelte-1io85vl):focus {
		box-shadow: 0 0px 8px var(--accent-color);
		border-radius: 1.5em;
	}
	div.container.svelte-1p54cvv {
		display: block;
		width: 100%;
	}

	.input-container.svelte-1p54cvv {
		display: flex;
		position: relative;
		align-items: flex-end;
	}

	.dialogue-container.svelte-1p54cvv {
		border: none;
		border-radius: var(--input-radius);
		background: var(--input-background-fill);
		padding: var(--spacing-md);
		margin-bottom: var(--spacing-sm);
		position: relative;
	}

	.dialogue-line.svelte-1p54cvv {
		display: flex;
		align-items: center;
		margin-bottom: var(--spacing-sm);
	}

	.dialogue-line.svelte-1p54cvv:has(.action-column.hidden:where(.svelte-1p54cvv)) .text-column:where(.svelte-1p54cvv) {
		margin-right: 0;
	}

	.speaker-column.svelte-1p54cvv {
		flex: 0 0 150px;
		margin-right: var(--spacing-sm);
		display: flex;
		align-items: center;
	}

	.speaker-column.svelte-1p54cvv textarea:where(.svelte-1p54cvv) {
		background: var(--speaker-bg-color);
		transition: background-color 0.2s ease;
		border: 1px solid var(--border-color-primary);
		border-radius: var(--radius-sm);
		padding: var(--input-padding);
		color: var(--body-text-color);
		font-weight: var(--input-text-weight);
		font-size: var(--input-text-size);
		line-height: var(--line-sm);
		resize: none;
		width: 100%;
		box-sizing: border-box;
		height: auto;
		min-height: 30px;
		max-height: none;
		margin-top: 0px;
		margin-bottom: 0px;
		z-index: 1;
		display: block;
		position: relative;
		white-space: pre-wrap;
		word-wrap: break-word;
		overflow-wrap: break-word;
		overflow: hidden;
	}

	.text-column.svelte-1p54cvv {
		flex: 1;
		margin-right: var(--spacing-sm);
	}

	.text-column.svelte-1p54cvv textarea:where(.svelte-1p54cvv) {
		width: 100%;
		padding: var(--spacing-sm);
		border: 1px solid var(--border-color-primary);
		border-radius: var(--radius-sm);
		color: var(--body-text-color);
		background: var(--speaker-bg-color);
		transition: background-color 0.2s ease;
		height: auto;
		min-height: 30px;
		max-height: none;
		flex-grow: 1;
		margin-top: 0px;
		margin-bottom: 0px;
		resize: none;
		z-index: 1;
		display: block;
		position: relative;
		padding: var(--input-padding);
		width: 100%;
		color: var(--body-text-color);
		font-weight: var(--input-text-weight);
		font-size: var(--input-text-size);
		line-height: var(--line-sm);
		white-space: pre-wrap;
		word-wrap: break-word;
		overflow-wrap: break-word;
		overflow: hidden;
		box-sizing: border-box;
	}

	.text-column.svelte-1p54cvv textarea:where(.svelte-1p54cvv) {
		color: var(--body-text-color);
	}

	.dialogue-line[style*="--speaker-bg-color: rgba"].svelte-1p54cvv .text-column:where(.svelte-1p54cvv) textarea:where(.svelte-1p54cvv),
	.dialogue-line[style*="--speaker-bg-color: rgba"].svelte-1p54cvv .speaker-column:where(.svelte-1p54cvv) textarea:where(.svelte-1p54cvv) {
		color: black;
	}

	textarea.svelte-1p54cvv {
		flex-grow: 1;
		outline: none !important;
		margin-top: 0px;
		margin-bottom: 0px;
		resize: none;
		z-index: 1;
		display: block;
		position: relative;
		outline: none !important;
		background: var(--input-background-fill);
		padding: var(--input-padding);
		width: 100%;
		color: var(--body-text-color);
		font-weight: var(--input-text-weight);
		font-size: var(--input-text-size);
		line-height: var(--line-sm);
		box-shadow: var(--input-shadow);
		border: var(--input-border-width) solid var(--input-border-color);
		border-radius: var(--input-radius);
	}

	textarea.svelte-1p54cvv:disabled {
		-webkit-opacity: 1;
		opacity: 1;
	}

	textarea.svelte-1p54cvv:focus {
		box-shadow: var(--input-shadow-focus);
		border-color: var(--input-border-color-focus);
		background: var(--input-background-fill-focus);
	}

	textarea.svelte-1p54cvv::placeholder {
		color: var(--input-placeholder-color);
	}

	.action-column.svelte-1p54cvv {
		display: flex;
		justify-content: center;
	}

	.add-button.svelte-1p54cvv {
		display: flex;
		justify-content: center;
		align-items: center;
		width: 25px;
		height: 25px;
		border: none;
		background: transparent;
		cursor: pointer;
	}

	.delete-button.svelte-1p54cvv {
		display: flex;
		justify-content: center;
		align-items: center;
		width: 15px;
		height: 15px;
	}

	.add-button.svelte-1p54cvv:hover {
		color: var(--color-accent);
	}

	.switch-container.svelte-1p54cvv {
		display: flex;
		justify-content: flex-start;
		transition: opacity 0.2s ease-in-out;
	}

	.switch-container.switch-disabled.svelte-1p54cvv {
		opacity: 0.6;
		pointer-events: none;
	}

	.switch-container.top-switch.svelte-1p54cvv {
		margin-bottom: var(--spacing-sm);
		justify-content: flex-end;
	}

	.submit-container.svelte-1p54cvv {
		display: flex;
		justify-content: flex-end;
		margin-top: var(--spacing-sm);
	}

	.submit-container.svelte-1p54cvv button[disabled]:where(.svelte-1p54cvv) {
		cursor: not-allowed;
	}

	.submit-button.svelte-1p54cvv {
		border: none;
		text-align: center;
		text-decoration: none;
		font-size: 14px;
		cursor: pointer;
		border-radius: 15px;
		min-width: 30px;
		height: 30px;
		flex-shrink: 0;
		display: flex;
		justify-content: center;
		align-items: center;
		background: var(--button-secondary-background-fill);
		color: var(--button-secondary-text-color);
	}

	.submit-button.svelte-1p54cvv:hover {
		background: var(--button-secondary-background-fill-hover);
	}

	.submit-button.svelte-1p54cvv:active {
		box-shadow: var(--button-shadow-active);
	}

	.submit-button.svelte-1p54cvv svg {
		height: 22px;
		width: 22px;
	}

	.tag-menu.svelte-1p54cvv {
		position: absolute;
		width: 100%;
		top: 100%;
		left: 0;
	}

	.tag-menu-plain-text.svelte-1p54cvv {
		position: relative;
		width: 100%;
	}

	.tag-menu-plain-text.svelte-1p54cvv .options {
		position: static !important;
		width: 100% !important;
		max-height: none !important;
		top: auto !important;
		bottom: auto !important;
	}

	.hidden.svelte-1p54cvv {
		display: none;
	}

	.loading-overlay.svelte-1p54cvv {
		position: absolute;
		top: 0;
		left: 0;
		right: 0;
		bottom: 0;
		background: var(--input-background-fill);
		opacity: 0.95;
		backdrop-filter: blur(2px);
		display: flex;
		flex-direction: column;
		align-items: center;
		justify-content: center;
		z-index: 10;
		border-radius: var(--input-radius);
	}

	.loading-spinner.svelte-1p54cvv {
		width: 24px;
		height: 24px;
		border: 2px solid var(--border-color-primary);
		border-top: 2px solid var(--color-accent);
		border-radius: 50%;
		animation: svelte-1p54cvv-spin 1s linear infinite;
		margin-bottom: var(--spacing-sm);
	}

	@keyframes svelte-1p54cvv-spin {
		0% {
			transform: rotate(0deg);
		}
		100% {
			transform: rotate(360deg);
		}
	}

	.loading-text.svelte-1p54cvv {
		color: var(--body-text-color);
		font-size: var(--text-sm);
		font-weight: 500;
		opacity: 0.8;
	}

	.dialogue-container.loading.svelte-1p54cvv,
	.textarea-container.loading.svelte-1p54cvv {
		position: relative;
		opacity: 0.7;
		transition: opacity 0.3s ease-in-out;
	}

	.dialogue-container.svelte-1p54cvv,
	.textarea-container.svelte-1p54cvv {
		transition: opacity 0.3s ease-in-out;
	}