import { o as ordered_colors } from './i18n-CGlVUOvE.js';

const get_next_color = (index) => {
  return ordered_colors[index % ordered_colors.length];
};

export { get_next_color as g };
//# sourceMappingURL=color-DjQxWyAx.js.map
