import './i18n-CGlVUOvE.js';
import { a4 as text, t as template_effect, a as append, X as set_text, a5 as next } from './index-Bq2njFOY.js';

function Example($$anchor, $$props) {
	next();

	var text$1 = text();

	template_effect(() => set_text(text$1, $$props.value || ""));
	append($$anchor, text$1);
}

export { Example as default };
//# sourceMappingURL=Example-kRad1aPe.js.map
