
	.container.svelte-g2cwl3 {
		padding: var(--block-padding);
	}
	.output-class.svelte-g2cwl3 {
		display: flex;
		justify-content: center;
		align-items: center;
		padding: var(--size-6) var(--size-4);
		color: var(--body-text-color);
		font-weight: var(--weight-bold);
		font-size: var(--text-xxl);
	}

	.confidence-set.svelte-g2cwl3 {
		display: flex;
		justify-content: space-between;
		align-items: flex-start;
		margin-bottom: var(--size-2);
		color: var(--body-text-color);
		line-height: var(--line-none);
		font-family: var(--font-mono);
		width: 100%;
	}

	.confidence-set.svelte-g2cwl3:last-child {
		margin-bottom: 0;
	}

	.inner-wrap.svelte-g2cwl3 {
		flex: 1 1 0%;
		display: flex;
		flex-direction: column;
	}

	.bar.svelte-g2cwl3 {
		appearance: none;
		-webkit-appearance: none;
		-moz-appearance: none;
		align-self: flex-start;
		margin-bottom: var(--size-1);
		border-radius: var(--radius-md);
		background: var(--stat-background-fill);
		height: var(--size-1);
		border: none;
	}

	.bar.svelte-g2cwl3::-moz-meter-bar {
		border-radius: var(--radius-md);
		background: var(--stat-background-fill);
	}

	.bar.svelte-g2cwl3::-webkit-meter-bar {
		border-radius: var(--radius-md);
		background: var(--stat-background-fill);
		border: none;
	}

	.bar.svelte-g2cwl3::-webkit-meter-optimum-value,
	.bar.svelte-g2cwl3::-webkit-meter-suboptimum-value,
	.bar.svelte-g2cwl3::-webkit-meter-even-less-good-value {
		border-radius: var(--radius-md);
		background: var(--stat-background-fill);
	}

	.bar.svelte-g2cwl3::-ms-fill {
		border-radius: var(--radius-md);
		background: var(--stat-background-fill);
		border: none;
	}

	.label.svelte-g2cwl3 {
		display: flex;
		align-items: baseline;
	}

	.label.svelte-g2cwl3 > :where(.svelte-g2cwl3) + :where(.svelte-g2cwl3) {
		margin-left: var(--size-2);
	}

	.confidence-set.svelte-g2cwl3:hover .label:where(.svelte-g2cwl3) {
		color: var(--color-accent);
	}

	.confidence-set.svelte-g2cwl3:focus .label:where(.svelte-g2cwl3) {
		color: var(--color-accent);
	}

	.text.svelte-g2cwl3 {
		line-height: var(--line-md);
		text-align: left;
	}

	.line.svelte-g2cwl3 {
		flex: 1 1 0%;
		border: 1px dashed var(--border-color-primary);
		padding-right: var(--size-4);
		padding-left: var(--size-4);
	}

	.confidence.svelte-g2cwl3 {
		margin-left: auto;
		text-align: right;
	}