<script>
	export let classNames = "";
</script>

<svg
	class={classNames}
	xmlns="http://www.w3.org/2000/svg"
	aria-hidden="true"
	fill="currentColor"
	focusable="false"
	role="img"
	width="1em"
	height="1em"
	preserveAspectRatio="xMidYMid meet"
	viewBox="0 0 32 32"
>
	<path
		d="M28,10V28H10V10H28m0-2H10a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V10a2,2,0,0,0-2-2Z"
		transform="translate(0)"
	/>
	<path d="M4,18H2V4A2,2,0,0,1,4,2H18V4H4Z" transform="translate(0)" /><rect
		fill="none"
		width="32"
		height="32"
	/>
</svg>

<style>
	.icon-size {
		width: 0.75rem;
		height: 0.75rem;
	}

	@media (max-width: 640px) {
		.icon-size {
			width: 0.625rem;
			height: 0.625rem;
		}
	}
</style>
