import { p as prop, s as slot, b as set_class, a as set_attribute, f as set_style } from './i18n-CGlVUOvE.js';
import { t as template_effect, a as append, Q as child, R as from_html, T as reset } from './index-Bq2njFOY.js';

var root = from_html(`<div><!></div>`);

function BaseForm($$anchor, $$props) {

	let label = prop($$props, 'label', 3, undefined);
	var div = root();
	let classes;
	let styles;
	var node = child(div);

	slot(node, $$props, 'default', {}, null);
	reset(div);

	template_effect(() => {
		classes = set_class(div, 1, 'form svelte-d5xbca', null, classes, {
			hidden: $$props.visible === false,
			'hidden-css': $$props.visible === "hidden"
		});

		set_attribute(div, 'role', label() ? "group" : undefined);
		set_attribute(div, 'aria-label', label());

		styles = set_style(div, '', styles, {
			'flex-grow': $$props.scale,
			'min-width': `calc(min(${$$props.min_width}px, 100%))`
		});
	});

	append($$anchor, div);
}

export { BaseForm as B };
//# sourceMappingURL=BaseForm-BF0VUPNl.js.map
