
	.container.svelte-xds4q5 {
		border-radius: var(--radius-lg);
		overflow: hidden;
	}

	.container.selected.svelte-xds4q5 {
		border: 2px solid var(--border-color-accent);
	}

	.images-wrapper.svelte-xds4q5 {
		display: flex;
		gap: var(--spacing-sm);
	}

	.container.table.svelte-xds4q5 .images-wrapper:where(.svelte-xds4q5) {
		flex-direction: row;
		align-items: center;
		padding: var(--spacing-sm);
		border: 1px solid var(--border-color-primary);
		border-radius: var(--radius-lg);
		background: var(--background-fill-secondary);
	}

	.container.gallery.svelte-xds4q5 .images-wrapper:where(.svelte-xds4q5) {
		flex-direction: row;
		gap: 0;
	}

	.image-container.svelte-xds4q5 {
		position: relative;
		flex-shrink: 0;
	}

	.container.table.svelte-xds4q5 .image-container:where(.svelte-xds4q5) {
		width: var(--size-12);
		height: var(--size-12);
	}

	.container.gallery.svelte-xds4q5 .image-container:where(.svelte-xds4q5) {
		width: var(--size-20);
		height: var(--size-20);
		margin-left: calc(-1 * var(--size-8));
	}

	.container.gallery.svelte-xds4q5 .image-container:where(.svelte-xds4q5):first-child {
		margin-left: 0;
	}

	.more-indicator.svelte-xds4q5 {
		display: flex;
		align-items: center;
		justify-content: center;
		font-size: var(--text-lg);
		font-weight: bold;
		color: var(--border-color-primary);
	}

	.container.table.svelte-xds4q5 .more-indicator:where(.svelte-xds4q5) {
		width: var(--size-12);
		height: var(--size-12);
	}

	.container.gallery.svelte-xds4q5 .more-indicator:where(.svelte-xds4q5) {
		width: var(--size-20);
		height: var(--size-20);
		margin-left: calc(-1 * var(--size-8));
		margin-right: calc(-1 * var(--size-6));
	}

	.image-container.svelte-xds4q5 img:where(.svelte-xds4q5),
	.image-container.svelte-xds4q5 video:where(.svelte-xds4q5) {
		width: 100%;
		height: 100%;
		object-fit: cover;
		border-radius: var(--radius-md);
	}

	.caption.svelte-xds4q5 {
		position: absolute;
		bottom: 0;
		left: 0;
		right: 0;
		background: rgba(0, 0, 0, 0.7);
		color: white;
		padding: var(--spacing-xs);
		font-size: var(--text-xs);
		text-align: center;
		border-radius: 0 0 var(--radius-md) var(--radius-md);
		overflow: hidden;
		text-overflow: ellipsis;
		white-space: nowrap;
	}

	.container.table.svelte-xds4q5 .caption:where(.svelte-xds4q5) {
		display: none;
	}