const _name = "Bahasa Indonesia";
const annotated_image = {"annotated_image":"Gambar Beranotasi"};
const audio = {"allow_recording_access":"Mohon izinkan akses ke mikrofon untuk merekam.","audio":"Audio","record_from_microphone":"Rekam dari mikrofon","stop_recording":"Hentikan rekaman","no_device_support":"Perangkat media tidak dapat diakses. Pastikan Anda menjalankan dari sumber yang aman (https) atau localhost (atau Anda telah meneruskan sertifikat SSL yang valid ke ssl_verify), dan Anda telah mengizinkan akses browser ke perangkat Anda.","stop":"Berhenti","resume":"Lanjutkan","record":"Rekam","no_microphone":"Tidak ada mikrofon yang ditemukan","pause":"Jeda","play":"Putar","waiting":"Menunggu","drop_to_upload":"Letakkan file audio di sini untuk mengunggah"};
const blocks = {"connection_can_break":"Di perangkat seluler, koneksi dapat terputus jika tab ini tidak dalam fokus atau perangkat dalam mode tidur, sehingga Anda kehilangan posisi dalam antrian.","long_requests_queue":"Ada antrian panjang dari permintaan yang tertunda. Gandakan Ruang ini untuk melompati antrian.","lost_connection":"Koneksi terputus karena meninggalkan halaman. Bergabung kembali ke antrian...","waiting_for_inputs":"Menunggu file selesai diunggah, mohon coba lagi."};
const checkbox = {"checkbox":"Kotak centang","checkbox_group":"Grup kotak centang"};
const code = {"code":"Kode"};
const color_picker = {"color_picker":"Pemilih Warna"};
const common = {"built_with":"dibuat dengan","built_with_gradio":"Dibuat dengan Gradio","clear":"Bersihkan","download":"Unduh","edit":"Edit","empty":"Kosong","error":"Error","hosted_on":"Di-hosting di","loading":"Memuat","logo":"logo","or":"atau","remove":"Hapus","settings":"Pengaturan","share":"Bagikan","submit":"Kirim","undo":"Urungkan","no_devices":"Tidak ada perangkat yang ditemukan","language":"Bahasa","display_theme":"Tema Tampilan","pwa":"Aplikasi Web Progresif"};
const dataframe = {"incorrect_format":"Format salah, hanya file CSV dan TSV yang didukung","new_column":"Tambah kolom","new_row":"Baris baru","add_row_above":"Tambah baris di atas","add_row_below":"Tambah baris di bawah","add_column_left":"Tambah kolom ke kiri","add_column_right":"Tambah kolom ke kanan","delete_row":"Hapus baris","delete_column":"Hapus kolom","sort_column":"Urutkan kolom","sort_ascending":"Urutkan menaik","sort_descending":"Urutkan menurun","drop_to_upload":"Letakkan file CSV atau TSV di sini untuk mengimpor data ke dataframe","clear_sort":"Bersihkan pengurutan"};
const dropdown = {"dropdown":"Dropdown"};
const errors = {"build_error":"ada error saat membangun","config_error":"ada error konfigurasi","contact_page_author":"Mohon hubungi penulis halaman untuk memberitahu mereka.","no_app_file":"tidak ada file aplikasi","runtime_error":"ada error runtime","space_not_working":"\"Ruang tidak berfungsi karena\" {0}","space_paused":"ruang sedang dijeda","use_via_api":"Gunakan melalui API"};
const file = {"uploading":"Mengunggah..."};
const highlighted_text = {"highlighted_text":"Teks yang Disorot"};
const image = {"allow_webcam_access":"Mohon izinkan akses ke webcam untuk merekam.","brush_color":"Warna kuas","brush_radius":"Radius kuas","image":"Gambar","remove_image":"Hapus Gambar","select_brush_color":"Pilih warna kuas","start_drawing":"Mulai menggambar","use_brush":"Gunakan kuas","drop_to_upload":"Letakkan file gambar di sini untuk mengunggah"};
const label = {"label":"Label"};
const login = {"enable_cookies":"Jika Anda mengunjungi Ruang HuggingFace dalam mode Penyamaran, Anda harus mengaktifkan cookie pihak ketiga.","incorrect_credentials":"Kredensial salah","username":"nama pengguna","password":"kata sandi","login":"Masuk"};
const number = {"number":"Nomor"};
const plot = {"plot":"Plot"};
const radio = {"radio":"Tombol Radio"};
const slider = {"slider":"Penggeser"};
const upload_text = {"click_to_upload":"Klik untuk Mengunggah","drop_audio":"Letakkan Audio di Sini","drop_csv":"Letakkan CSV di Sini","drop_file":"Letakkan File di Sini","drop_image":"Letakkan Gambar di Sini","drop_video":"Letakkan Video di Sini","drop_gallery":"Letakkan Media di Sini","paste_clipboard":"Tempel dari Papan Klip"};
const video = {"drop_to_upload":"Letakkan file video di sini untuk mengunggah"};
const chatbot = {"edit":"Edit","retry":"Coba lagi","undo":"Urungkan","submit":"Kirim","cancel":"Batal","like":"Suka","dislike":"Tidak Suka","clear":"Bersihkan obrolan"};
const id = {
  _name,
  "3D_model": {"3d_model":"Model 3D","drop_to_upload":"Letakkan file model 3D (.obj, .glb, .stl, .gltf, .splat, atau .ply) di sini untuk mengunggah"},
  annotated_image,
  audio,
  blocks,
  checkbox,
  code,
  color_picker,
  common,
  dataframe,
  dropdown,
  errors,
  file,
  highlighted_text,
  image,
  label,
  login,
  number,
  plot,
  radio,
  slider,
  upload_text,
  video,
  chatbot,
};

export { _name, annotated_image, audio, blocks, chatbot, checkbox, code, color_picker, common, dataframe, id as default, dropdown, errors, file, highlighted_text, image, label, login, number, plot, radio, slider, upload_text, video };
//# sourceMappingURL=id-DTBwfi3A.js.map
