import './async-D55cHugf.js';
import { m as attributes, j as clsx } from './index-K3l_dLem.js';

/* empty css                                    */
function Image($$renderer, $$props) {
  $$renderer.component(($$renderer2) => {
    let { src, restProps, data_testid, class_names } = $$props;
    $$renderer2.push(`<img${attributes(
      {
        src,
        class: clsx((class_names || []).join(" ")),
        "data-testid": data_testid,
        ...restProps
      },
      "svelte-1jk6tax"
    )} onload="this.__e=event" onerror="this.__e=event"/>`);
  });
}

export { Image as I };
//# sourceMappingURL=Image-CZw3rP1w.js.map
