const _name = "Français";
const annotated_image = {"annotated_image":"Image annotée"};
const audio = {"allow_recording_access":"Veuillez autoriser l'accès au microphone pour l'enregistrement.","audio":"Audio","record_from_microphone":"Enregistrer depuis le microphone","stop_recording":"Arrêter l'enregistrement","no_device_support":"Impossible d'accéder aux périphériques multimédias. Assurez-vous que vous êtes sur une source sécurisée (https) ou localhost (ou avez passé un certificat SSL valide à ssl_verify), et que vous avez autorisé l'accès du navigateur à votre appareil.","stop":"Arrêter","resume":"Reprendre","record":"Enregistrer","no_microphone":"Aucun microphone trouvé","pause":"Pause","play":"Lecture","waiting":"En attente","drop_to_upload":"Déposez un fichier audio ici pour le télécharger"};
const blocks = {"connection_can_break":"Sur mobile, la connexion peut être interrompue si cet onglet perd le focus ou si l'appareil se met en veille, perdant votre position dans la file d'attente.","long_requests_queue":"Il y a une longue file d'attente de requêtes en attente. Dupliquez ce Space pour la contourner.","lost_connection":"Connexion perdue en quittant la page. Retour à la file d'attente...","waiting_for_inputs":"En attente de la fin du téléchargement des fichier(s), veuillez réessayer."};
const checkbox = {"checkbox":"Case à cocher","checkbox_group":"Groupe de cases à cocher"};
const code = {"code":"Code"};
const color_picker = {"color_picker":"Sélecteur de couleur"};
const common = {"built_with":"créé avec","built_with_gradio":"Créé avec Gradio","clear":"Effacer","download":"Télécharger","edit":"Modifier","empty":"Vide","flag":"Marquer","error":"Erreur","hosted_on":"Hébergé sur","loading":"Chargement","logo":"logo","or":"ou","remove":"Supprimer","settings":"Paramètres","share":"Partager","submit":"Envoyer","undo":"Annuler","no_devices":"Aucun périphérique trouvé","language":"Langue","display_theme":"Thème d'affichage","pwa":"Application web progressive","run":"Exécuter"};
const dataframe = {"incorrect_format":"Format incorrect, seuls les fichiers CSV et TSV sont pris en charge","new_column":"Ajouter une colonne","new_row":"Nouvelle ligne","add_row_above":"Ajouter une ligne au-dessus","add_row_below":"Ajouter une ligne en dessous","add_column_left":"Ajouter une colonne à gauche","add_column_right":"Ajouter une colonne à droite","delete_row":"Supprimer la ligne","delete_column":"Supprimer la colonne","sort_column":"Trier la colonne","sort_ascending":"Trier par ordre croissant","sort_descending":"Trier par ordre décroissant","drop_to_upload":"Déposez ici les fichiers CSV ou TSV pour importer les données dans le dataframe.","clear_sort":"Effacer le tri"};
const dropdown = {"dropdown":"Menu déroulant"};
const errors = {"build_error":"il y a une erreur de construction","config_error":"il y a une erreur de configuration","contact_page_author":"Veuillez contacter l'auteur de la page pour l'informer.","no_app_file":"il n'y a pas de fichier d'application","runtime_error":"il y a une erreur d'exécution","space_not_working":"\"Le Space ne fonctionne pas car\" {0}","space_paused":"le Space est en pause","use_via_api":"Utiliser via API","use_via_api_or_mcp":"Utiliser via API ou MCP"};
const file = {"uploading":"Téléchargement..."};
const highlighted_text = {"highlighted_text":"Texte surligné"};
const image = {"allow_webcam_access":"Veuillez autoriser l'accès à la webcam pour l'enregistrement.","brush_color":"Couleur du pinceau","brush_radius":"Taille du pinceau","image":"Image","remove_image":"Supprimer l'image","select_brush_color":"Sélectionner la couleur du pinceau","start_drawing":"Commencer à dessiner","use_brush":"Utiliser le pinceau","drop_to_upload":"Déposez un fichier image ici pour télécharger"};
const label = {"label":"Étiquette"};
const login = {"enable_cookies":"Si vous visitez un Space HuggingFace en mode Incognito, vous devez activer les cookies tiers.","incorrect_credentials":"Identifiants incorrects","username":"nom d'utilisateur","password":"mot de passe","login":"Connexion"};
const number = {"number":"Nombre"};
const plot = {"plot":"Graphique"};
const radio = {"radio":"Bouton radio"};
const slider = {"slider":"Curseur"};
const upload_text = {"click_to_upload":"Cliquez pour télécharger un fichier","drop_audio":"Déposez l'audio ici","drop_csv":"Déposez le fichier CSV ici","drop_file":"Déposez le fichier ici","drop_image":"Déposez l'image ici","drop_video":"Déposez la vidéo ici","drop_gallery":"Déposez les médias ici","paste_clipboard":"Coller depuis le presse-papiers"};
const video = {"drop_to_upload":"Déposez un fichier vidéo ici pour le télécharger"};
const chatbot = {"edit":"Modifier","retry":"Réessayer","undo":"Annuler","submit":"Envoyer","cancel":"Annuler","like":"J'aime","dislike":"Je n'aime pas","clear":"Effacer la conversation"};
const fr = {
  _name,
  "3D_model": {"3d_model":"Modèle 3D","drop_to_upload":"Déposez un fichier image ici pour le télécharger"},
  annotated_image,
  audio,
  blocks,
  checkbox,
  code,
  color_picker,
  common,
  dataframe,
  dropdown,
  errors,
  file,
  highlighted_text,
  image,
  label,
  login,
  number,
  plot,
  radio,
  slider,
  upload_text,
  video,
  chatbot,
};

export { _name, annotated_image, audio, blocks, chatbot, checkbox, code, color_picker, common, dataframe, fr as default, dropdown, errors, file, highlighted_text, image, label, login, number, plot, radio, slider, upload_text, video };
//# sourceMappingURL=fr-Xtgf04nj.js.map
