import { S as ShaderStore } from './index-BeVTUo08.js';

// Do not edit.
const name = "kernelBlurVaryingDeclaration";
const shader = `varying sampleCoord{X}: vec2f;`;
// Sideeffect
if (!ShaderStore.IncludesShadersStoreWGSL[name]) {
    ShaderStore.IncludesShadersStoreWGSL[name] = shader;
}
//# sourceMappingURL=kernelBlurVaryingDeclaration-tkHwqdUu.js.map
