from __future__ import annotations


def launch(
    app_file: str = "app.py",  # noqa: ARG001
):
    raise DeprecationWarning(
        "The 'gradio sketch' command has been deprecated and removed in Gradio 6. "
        "Consider using 'gradio --vibe' instead. "
    )
