
	.tabs.svelte-11gaq1 {
		position: relative;
		display: flex;
		flex-direction: column;
		gap: var(--layout-gap);
	}

	.hide.svelte-11gaq1 {
		display: none;
	}

	.hidden.svelte-11gaq1 {
		display: none !important;
	}

	.tab-wrapper.svelte-11gaq1 {
		display: flex;
		align-items: center;
		justify-content: space-between;
		position: relative;
		height: var(--size-8);
		padding-bottom: var(--size-2);
	}

	.tab-container.svelte-11gaq1 {
		display: flex;
		align-items: center;
		width: 100%;
		position: relative;
		overflow: hidden;
		height: var(--size-8);
	}

	.tab-container.svelte-11gaq1::after {
		content: "";
		position: absolute;
		bottom: 0;
		left: 0;
		right: 0;
		height: 1px;
		background-color: var(--border-color-primary);
	}

	.overflow-menu.svelte-11gaq1 {
		flex-shrink: 0;
		margin-left: var(--size-2);
	}

	button.svelte-11gaq1 {
		margin-bottom: 0;
		border: none;
		border-radius: 0;
		padding: 0 var(--size-4);
		color: var(--body-text-color);
		font-weight: var(--section-header-text-weight);
		font-size: var(--section-header-text-size);
		transition: background-color color 0.2s ease-out;
		background-color: transparent;
		height: 100%;
		display: flex;
		align-items: center;
		white-space: nowrap;
		position: relative;
	}

	button.svelte-11gaq1:disabled {
		opacity: 0.5;
		cursor: not-allowed;
	}

	button.svelte-11gaq1:hover:not(:disabled):not(.selected) {
		background-color: var(--background-fill-secondary);
		color: var(--body-text-color);
	}

	.selected.svelte-11gaq1 {
		background-color: transparent;
		color: var(--color-accent);
		position: relative;
	}

	.selected.svelte-11gaq1::after {
		content: "";
		position: absolute;
		bottom: 0;
		left: 0;
		width: 100%;
		height: 2px;
		background-color: var(--color-accent);
		animation: svelte-11gaq1-fade-grow 0.2s ease-out forwards;
		transform-origin: center;
		z-index: 1;
	}

	@keyframes svelte-11gaq1-fade-grow {
		from {
			opacity: 0;
			transform: scaleX(0.8);
		}
		to {
			opacity: 1;
			transform: scaleX(1);
		}
	}

	.overflow-dropdown.svelte-11gaq1 {
		position: absolute;
		top: calc(100% + var(--size-2));
		right: 0;
		background-color: var(--background-fill-primary);
		border: 1px solid var(--border-color-primary);
		border-radius: var(--radius-sm);
		z-index: var(--layer-5);
		box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
		padding: var(--size-2);
		min-width: 150px;
		width: max-content;
	}

	.overflow-dropdown.svelte-11gaq1 button:where(.svelte-11gaq1) {
		display: block;
		width: 100%;
		text-align: left;
		padding: var(--size-2);
		white-space: nowrap;
		overflow: hidden;
		text-overflow: ellipsis;
	}

	.overflow-menu.svelte-11gaq1 > button:where(.svelte-11gaq1) {
		padding: var(--size-1) var(--size-2);
		min-width: auto;
		border: 1px solid var(--border-color-primary);
		border-radius: var(--radius-sm);
		display: flex;
		align-items: center;
		justify-content: center;
	}

	.overflow-menu.svelte-11gaq1 > button:where(.svelte-11gaq1):hover {
		background-color: var(--background-fill-secondary);
	}

	.overflow-menu.svelte-11gaq1 svg {
		width: 16px;
		height: 16px;
	}

	.overflow-item-selected.svelte-11gaq1 svg {
		color: var(--color-accent);
	}

	.visually-hidden.svelte-11gaq1 {
		position: absolute;
		width: 1px;
		height: 1px;
		padding: 0;
		margin: -1px;
		overflow: hidden;
		clip: rect(0, 0, 0, 0);
		white-space: nowrap;
		border: 0;
	}
	.stepper.svelte-1xpzbgb {
		position: relative;
		display: flex;
		flex-direction: column;
		gap: var(--layout-gap);
	}

	.compact.stepper.svelte-1xpzbgb {
		gap: 0;
	}

	.hide.svelte-1xpzbgb {
		display: none;
	}

	.stepper-wrapper.svelte-1xpzbgb {
		display: flex;
		align-items: center;
		position: relative;
		padding-top: var(--size-4);
		padding-bottom: calc(var(--label-height) + var(--size-4));
	}

	.compact.svelte-1xpzbgb .stepper-wrapper:where(.svelte-1xpzbgb) {
		padding-top: var(--size-2);
		padding-bottom: var(--size-6);
	}

	.stepper-container.svelte-1xpzbgb {
		display: flex;
		justify-content: space-between;
		align-items: flex-start;
		width: 100%;
		position: relative;
		padding: var(--size-2);
		gap: var(--size-1);
	}

	.compact.svelte-1xpzbgb .stepper-container:where(.svelte-1xpzbgb) {
		justify-content: center;
		gap: 2px;
		padding: 0;
	}

	.step-item.svelte-1xpzbgb {
		display: flex;
		align-items: center;
		justify-content: center;
		flex: 1 1 0;
		position: relative;
	}

	.compact.svelte-1xpzbgb .step-item:where(.svelte-1xpzbgb) {
		/* flex: 0 0 auto; */
		width: 100%;
	}

	.step-button.svelte-1xpzbgb {
		position: relative;
		display: flex;
		flex-direction: column;
		align-items: center;
		justify-content: center;
		gap: var(--size-1);

		border: none;
		background: transparent;
		cursor: pointer;
		border-radius: var(--radius-md);
		transition: background-color 0.2s ease;
		font-size: var(--text-sm);
		color: var(--body-text-color-subdued);
		white-space: nowrap;
		z-index: 1;
		position: relative;
	}

	.compact.svelte-1xpzbgb .step-button:where(.svelte-1xpzbgb) {
		padding: 0;
		width: 100%;
		border: none;
	}

	.compact.svelte-1xpzbgb .step-number:where(.svelte-1xpzbgb) {
		height: 10px;
		width: 100%;
		border-radius: 0;
		border: none;
	}

	.step-button.svelte-1xpzbgb:hover:not(:disabled) {
		background-color: var(--background-fill-secondary);
	}

	.step-button.svelte-1xpzbgb:disabled {
		cursor: not-allowed;
		opacity: 0.5;
	}

	.step-button.active.svelte-1xpzbgb {
		color: var(--body-text-color);
	}

	.step-button.completed.svelte-1xpzbgb {
		color: var(--body-text-color);
	}

	.step-button.pending.svelte-1xpzbgb {
		color: var(--body-text-color-subdued);
	}

	.step-number.svelte-1xpzbgb {
		display: flex;
		align-items: center;
		justify-content: center;
		width: 32px;
		height: 32px;
		border-radius: 50%;
		font-size: var(--text-sm);
		font-weight: var(--weight-semibold);
		transition: background-color 0.2s ease;
		flex-shrink: 0;
	}

	.active.svelte-1xpzbgb .step-number:where(.svelte-1xpzbgb) {
		background-color: var(--color-accent);
		color: white;
		box-shadow: 0 0 0 4px rgba(var(--color-accent-rgb), 0.1);
	}

	.completed.svelte-1xpzbgb .step-number:where(.svelte-1xpzbgb) {
		background-color: var(--color-accent);
		color: white;
	}

	.compact.svelte-1xpzbgb .completed:where(.svelte-1xpzbgb) .step-number:where(.svelte-1xpzbgb) {
		color: transparent;
	}

	.compact.svelte-1xpzbgb .pending:where(.svelte-1xpzbgb) .step-number:where(.svelte-1xpzbgb) {
		color: transparent;
		background-color: var(--body-text-color-subdued);
	}

	.compact.svelte-1xpzbgb .active:where(.svelte-1xpzbgb) .step-number:where(.svelte-1xpzbgb) {
		color: transparent;
	}

	.pending.svelte-1xpzbgb .step-number:where(.svelte-1xpzbgb) {
		background-color: var(--button-secondary-background-fill);
		color: var(--button-secondary-text-color);
	}

	.compact.svelte-1xpzbgb .step-item:where(.svelte-1xpzbgb):last-child .step-number:where(.svelte-1xpzbgb) {
		border-top-right-radius: var(--radius-xs);
		border-bottom-right-radius: var(--radius-xs);
	}
	.compact.svelte-1xpzbgb .step-item:where(.svelte-1xpzbgb):first-child .step-number:where(.svelte-1xpzbgb) {
		border-top-left-radius: var(--radius-xs);
		border-bottom-left-radius: var(--radius-xs);
	}

	.step-label.svelte-1xpzbgb {
		font-size: var(--text-md);
		line-height: 1.2;
		text-align: center;
		max-width: 120px;
		position: absolute;
		bottom: -20px;
		display: none;
	}

	.step-label.visible.svelte-1xpzbgb {
		display: block;
	}

	.step-connector.svelte-1xpzbgb {
		width: 100%;
		height: 2px;
		background-color: var(--border-color-primary);
		transition: background-color 0.3s ease;
		z-index: 0;
		transform: translate(0, 15px);
	}

	.step-connector.completed.svelte-1xpzbgb {
		background-color: var(--color-accent);
	}

	.dark .pending.svelte-1xpzbgb .step-number:where(.svelte-1xpzbgb) {
		background-color: var(--neutral-800);
		color: var(--neutral-400);
		border-color: var(--neutral-600);
	}

	.dark .step-connector.svelte-1xpzbgb {
		background-color: var(--neutral-600);
	}