
	.wrap.svelte-b2bl92 {
		position: relative;
		width: 100%;
		height: 100%;
		z-index: var(--layer-1);
		overflow: hidden;
	}

	.icon-wrap.svelte-b2bl92 {
		display: block;
		position: absolute;
		top: 50%;
		transform: translate(-20.5px, -50%);
		left: 10px;
		width: 40px;
		transition: 0.2s;
		color: var(--body-text-color);
		height: 30px;
		border-radius: 5px;
		background-color: var(--color-accent);
		display: flex;
		align-items: center;
		justify-content: center;
		z-index: var(--layer-3);
		box-shadow: 0px 0px 5px 2px rgba(0, 0, 0, 0.3);
		font-size: 12px;
	}

	.icon.left.svelte-b2bl92 {
		transform: rotate(135deg);
		text-shadow: -1px -1px 1px rgba(0, 0, 0, 0.1);
	}

	.icon.right.svelte-b2bl92 {
		transform: rotate(-45deg);
		text-shadow: -1px -1px 1px rgba(0, 0, 0, 0.1);
	}

	.icon.center.svelte-b2bl92 {
		display: block;
		width: 1px;
		height: 100%;
		background-color: var(--color);
		opacity: 0.1;
	}

	.icon-wrap.active.svelte-b2bl92 {
		opacity: 0;
	}

	.icon-wrap.disabled.svelte-b2bl92 {
		opacity: 0;
	}

	.outer.svelte-b2bl92 {
		width: 20px;
		height: 100%;
		position: absolute;
		cursor: grab;
		position: absolute;
		top: 0;
		left: -10px;
		pointer-events: auto;
		z-index: var(--layer-2);
	}
	.grab.svelte-b2bl92 {
		cursor: grabbing;
	}

	.inner.svelte-b2bl92 {
		width: 1px;
		height: 100%;
		background: var(--color);
		position: absolute;
		left: calc((100% - 2px) / 2);
	}

	.disabled.svelte-b2bl92 {
		cursor: auto;
	}

	.disabled.svelte-b2bl92 .inner:where(.svelte-b2bl92) {
		box-shadow: none;
	}

	.content.svelte-b2bl92 {
		width: 100%;
		height: 100%;
		display: flex;
		justify-content: center;
		align-items: center;
	}
	.preview.svelte-j3ek2n {
		object-fit: contain;
		width: 100%;
		transform-origin: top left;
		margin: auto;
	}

	.small.svelte-j3ek2n {
		max-height: 500px;
	}

	.upload.svelte-j3ek2n {
		object-fit: contain;
		max-height: 500px;
	}

	.fixed.svelte-j3ek2n {
		position: absolute;
		top: 0;
		left: 0;
		right: 0;
		bottom: 0;
	}

	.fullscreen.svelte-j3ek2n {
		width: 100%;
		height: 100%;
	}

	.image-container:fullscreen img.svelte-j3ek2n {
		width: 100%;
		height: 100%;
		max-height: none;
		max-width: none;
	}

	.hidden.svelte-j3ek2n {
		opacity: 0;
	}
	.slider-wrap.svelte-1880bc6 {
		user-select: none;
		height: 100%;
		width: 100%;
		position: relative;
		display: flex;
		align-items: center;
		justify-content: center;
	}

	.limit_height.svelte-1880bc6 img {
		max-height: 500px;
	}

	.image-container.svelte-1880bc6 {
		height: 100%;
		position: relative;
		min-width: var(--size-20);
	}
	div.svelte-2ufkjh {
		display: flex;
		position: absolute;
		top: var(--size-2);
		right: var(--size-2);
		justify-content: flex-end;
		gap: var(--spacing-sm);
		z-index: var(--layer-5);
	}
	.upload-wrap.svelte-1c8zs50 {
		display: flex;
		justify-content: center;
		align-items: center;
		height: 100%;
		width: 100%;
	}

	.wrap.svelte-1c8zs50 {
		width: 100%;
	}

	.half-wrap.svelte-1c8zs50 {
		width: 50%;
	}
	.image-container.svelte-1c8zs50,
	.empty-wrap.svelte-1c8zs50 {
		width: var(--size-full);
		height: var(--size-full);
	}

	.fixed.svelte-1c8zs50 {
		--anim-block-background-fill: 255, 255, 255;
		position: absolute;
		top: 0;
		left: 0;
		background-color: rgba(var(--anim-block-background-fill), 0.8);
		z-index: 0;
	}

	@media (prefers-color-scheme: dark) {
		.fixed.svelte-1c8zs50 {
			--anim-block-background-fill: 31, 41, 55;
		}
	}

	.side-by-side.svelte-1c8zs50 img {
		/* width: 100%; */
		width: 50%;
		object-fit: contain;
	}

	.empty-wrap.svelte-1c8zs50 {
		pointer-events: none;
	}

	.icon-buttons.svelte-1c8zs50 {
		display: flex;
		position: absolute;
		right: 8px;
		z-index: var(--layer-top);
		top: 8px;
	}