const _name = "اردو";
const common = { "built_with_gradio": "Gradio کے ساتھ بنایا گیا", "clear": "صاف کریں", "or": "یا", "submit": "جمع کریں", "settings": "ترتیبات", "built_with": "کے ساتھ بنایا گیا", "download": "ڈاؤن لوڈ کریں", "edit": "ترمیم کریں", "empty": "خالی", "error": "خطا", "hosted_on": "پر میزبانی کی جا رہی ہے", "loading": "لوڈ ہو رہا ہے", "logo": "لوگو", "remove": "حذف کریں", "share": "شیئر کریں", "undo": "واپس لیں", "no_devices": "کوئی ڈیوائس نہیں ملی", "language": "زبان", "display_theme": "تھیم کی نمائش", "pwa": "پروگریسیو ویب ایپ" };
const upload_text = { "click_to_upload": "اپ لوڈ کے لیے کلک کریں", "drop_audio": "یہاں آڈیو ڈراپ کریں", "drop_csv": "یہاں CSV ڈراپ کریں", "drop_file": "یہاں فائل ڈراپ کریں", "drop_image": "یہاں تصویر ڈراپ کریں", "drop_video": "یہاں ویڈیو ڈراپ کریں", "drop_gallery": "میڈیا یہاں ڈالیں", "paste_clipboard": "کلپ بورڈ سے پیسٹ کریں" };
const annotated_image = { "annotated_image": "تشریحی تصویر" };
const audio = { "allow_recording_access": "براہ مہربانی ریکارڈنگ کے لیے مائیکروفون تک رسائی کی اجازت دیں۔", "audio": "آڈیو", "drop_to_upload": "اپلوڈ کرنے کے لیے آڈیو فائل یہاں ڈراپ کریں", "record_from_microphone": "مائیکروفون سے ریکارڈ کریں", "stop_recording": "ریکارڈنگ بند کریں", "no_device_support": "میڈیا ڈیوائسز تک رسائی حاصل نہیں کی جا سکی۔ یقینی بنائیں کہ آپ محفوظ ذریعہ (https) یا localhost پر چلا رہے ہیں (یا آپ نے ssl_verify میں درست SSL سرٹیفکیٹ منتقل کیا ہے)، اور آپ نے براؤزر کو اپنے ڈیوائس تک رسائی کی اجازت دی ہے۔", "stop": "روکیں", "resume": "دوبارہ شروع کریں", "record": "ریکارڈ کریں", "no_microphone": "کوئی مائیکروفون نہیں ملا", "pause": "روکیں", "play": "چلائیں", "waiting": "انتظار کر رہا ہے" };
const blocks = { "connection_can_break": "موبائل پر، اگر اس ٹیب کا فوکس کھو جائے یا ڈیوائس سلیپ موڈ میں چلا جائے تو کنکشن ٹوٹ سکتا ہے، جس سے آپ قطار میں اپنی جگہ کھو سکتے ہیں۔", "long_requests_queue": "درخواستوں کی ایک لمبی قطار زیر التواء ہے۔ قطار چھوڑنے کے لیے اس Space کو ڈپلیکیٹ کریں۔", "lost_connection": "صفحہ چھوڑنے کی وجہ سے کنکشن کھو گیا۔ قطار میں دوبارہ شامل ہو رہا ہے...", "waiting_for_inputs": "فائل(وں) کے اپ لوڈ ہونے کا انتظار ہے، براہ کرم دوبارہ کوشش کریں۔" };
const checkbox = { "checkbox": "چیک باکس", "checkbox_group": "چیک باکس گروپ" };
const code = { "code": "کوڈ" };
const color_picker = { "color_picker": "رنگ منتخب کرنے والا" };
const dataframe = { "incorrect_format": "غلط فارمیٹ، صرف CSV اور TSV فائلوں کی حمایت کی جاتی ہے", "new_column": "کالم شامل کریں", "new_row": "نئی قطار", "add_row_above": "اوپر قطار شامل کریں", "add_row_below": "نیچے قطار شامل کریں", "delete_row": "قطار حذف کریں", "delete_column": "کالم حذف کریں", "add_column_left": "بائیں طرف کالم شامل کریں", "add_column_right": "دائیں طرف کالم شامل کریں", "sort_column": "کالم کو ترتیب دیں", "sort_ascending": "صعودی ترتیب دیں", "sort_descending": "نزولی ترتیب دیں", "drop_to_upload": "ڈیٹا کو ڈیٹا فریم میں درآمد کرنے کے لیے CSV یا TSV فائلیں یہاں ڈراپ کریں", "clear_sort": "ترتیب صاف کریں" };
const dropdown = { "dropdown": "ڈراپ ڈاؤن" };
const errors = { "build_error": "تعمیر میں خطا ہے", "config_error": "ترتیب میں خطا ہے", "contact_page_author": "براہ کرم صفحہ کے مصنف سے رابطہ کریں تاکہ انہیں مطلع کیا جا سکے۔", "no_app_file": "کوئی ایپ فائل نہیں ہے", "runtime_error": "رن ٹائم میں خطا ہے", "space_not_working": '"Space کام نہیں کر رہا ہے کیونکہ" {0}', "space_paused": "Space موقوف ہے", "use_via_api": "API کے ذریعے استعمال کریں", "use_via_api_or_mcp": "API یا MCP کے ذریعے استعمال کریں" };
const file = { "uploading": "اپلوڈ ہو رہا ہے..." };
const highlighted_text = { "highlighted_text": "نمایاں کردہ متن" };
const image = { "allow_webcam_access": "براہ مہربانی ریکارڈنگ کے لیے ویب کیم تک رسائی کی اجازت دیں۔", "brush_color": "برش کا رنگ", "brush_radius": "برش کا سائز", "image": "تصویر", "remove_image": "تصویر حذف کریں", "select_brush_color": "برش کا رنگ منتخب کریں", "start_drawing": "ڈرائنگ شروع کریں", "use_brush": "برش استعمال کریں", "drop_to_upload": "اپلوڈ کرنے کے لیے تصویر فائل یہاں ڈراپ کریں" };
const label = { "label": "لیبل" };
const login = { "enable_cookies": "اگر آپ انکوگنیٹو موڈ میں HuggingFace Space ملاحظہ کر رہے ہیں تو، آپ کو تیسرے فریق کے کوکیز کو فعال کرنا ہوگا۔", "incorrect_credentials": "غلط اسناد", "username": "صارف نام", "password": "پاس ورڈ", "login": "لاگ ان کریں" };
const number = { "number": "نمبر" };
const plot = { "plot": "گراف" };
const radio = { "radio": "ریڈیو بٹن" };
const slider = { "slider": "سلائیڈر" };
const video = { "drop_to_upload": "اپلوڈ کرنے کے لیے ویڈیو فائل یہاں ڈراپ کریں" };
const chatbot = { "edit": "ترمیم", "retry": "دوبارہ کوشش", "undo": "واپس", "submit": "جمع کریں", "cancel": "منسوخ", "like": "پسند", "dislike": "ناپسند", "clear": "گفتگو صاف کریں" };
const ur = {
  _name,
  common,
  upload_text,
  "3D_model": { "3d_model": "3D ماڈل", "drop_to_upload": "اپلوڈ کرنے کے لیے 3D ماڈل (.obj, .glb, .stl, .gltf, .splat، یا .ply) فائل یہاں ڈراپ کریں" },
  annotated_image,
  audio,
  blocks,
  checkbox,
  code,
  color_picker,
  dataframe,
  dropdown,
  errors,
  file,
  highlighted_text,
  image,
  label,
  login,
  number,
  plot,
  radio,
  slider,
  video,
  chatbot
};

export { _name, annotated_image, audio, blocks, chatbot, checkbox, code, color_picker, common, dataframe, ur as default, dropdown, errors, file, highlighted_text, image, label, login, number, plot, radio, slider, upload_text, video };
//# sourceMappingURL=ur-CmiNuJ_u.js.map
