import './i18n-CGlVUOvE.js';
import { a as append, f as from_svg } from './index-Bq2njFOY.js';

var root = from_svg(`<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="currentColor" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"><polygon points="5 3 19 12 5 21 5 3"></polygon></svg>`);

function Play($$anchor) {
	var svg = root();

	append($$anchor, svg);
}

export { Play as P };
//# sourceMappingURL=Play-CGGxKNeS.js.map
