import './async-D55cHugf.js';
import { s as slot } from './index-K3l_dLem.js';
import './escaping-CBnpiEl5.js';
import './context-DF4-UEpk.js';

function _layout($$renderer, $$props) {
  $$renderer.push(`<!--[-->`);
  slot($$renderer, $$props, "default", {}, null);
  $$renderer.push(`<!--]-->`);
}

export { _layout as default };
//# sourceMappingURL=_layout.svelte-q8pmoRpx.js.map
