
	.wrap.svelte-zxu34v {
		display: flex;
		flex-grow: 1;
		flex-direction: column;
		width: var(--size-full);
		font-weight: var(--body-text-weight);
		font-size: var(--body-text-size);
	}

	main.contain.svelte-zxu34v {
		display: flex;
		flex-direction: column;
	}

	footer.svelte-zxu34v {
		display: flex;
		justify-content: center;
		margin-top: var(--size-4);
		color: var(--body-text-color-subdued);
	}
	.divider.svelte-zxu34v {
		margin-left: var(--size-1);
		margin-right: var(--size-2);
	}

	.show-api.svelte-zxu34v,
	.settings.svelte-zxu34v,
	.record.svelte-zxu34v {
		display: flex;
		align-items: center;
	}
	.show-api.svelte-zxu34v:hover {
		color: var(--body-text-color);
	}

	.show-api.svelte-zxu34v img:where(.svelte-zxu34v) {
		margin-right: var(--size-1);
		margin-left: var(--size-2);
		width: var(--size-3);
	}

	.settings.svelte-zxu34v img:where(.svelte-zxu34v) {
		margin-right: var(--size-1);
		margin-left: var(--size-1);
		width: var(--size-4);
	}

	.record.svelte-zxu34v img:where(.svelte-zxu34v) {
		margin-right: var(--size-1);
		margin-left: var(--size-1);
		width: var(--size-3);
	}

	.built-with.svelte-zxu34v {
		display: flex;
		align-items: center;
	}

	.built-with.svelte-zxu34v:hover,
	.settings.svelte-zxu34v:hover,
	.record.svelte-zxu34v:hover {
		color: var(--body-text-color);
	}

	.built-with.svelte-zxu34v img:where(.svelte-zxu34v) {
		margin-right: var(--size-1);
		margin-left: var(--size-1);
		margin-bottom: 1px;
		width: var(--size-4);
	}

	.api-docs.svelte-zxu34v {
		display: flex;
		position: fixed;
		top: 0;
		right: 0;
		z-index: var(--layer-top);
		background: rgba(0, 0, 0, 0.5);
		width: var(--size-screen);
		height: var(--size-screen-h);
	}

	.backdrop.svelte-zxu34v {
		flex: 1 1 0%;
		-webkit-backdrop-filter: blur(4px);
		backdrop-filter: blur(4px);
	}

	.api-docs-wrap.svelte-zxu34v {
		box-shadow: var(--shadow-drop-lg);
		background: var(--background-fill-primary);
		overflow-x: hidden;
		overflow-y: auto;
	}

	@media (min-width: 768px) {
		.api-docs-wrap.svelte-zxu34v {
			border-top-left-radius: var(--radius-lg);
			border-bottom-left-radius: var(--radius-lg);
			width: 950px;
		}
	}

	@media (min-width: 1536px) {
		.api-docs-wrap.svelte-zxu34v {
			width: 1150px;
		}
	}

	#api-recorder-container.svelte-zxu34v {
		position: fixed;
		left: 10px;
		bottom: 10px;
		z-index: 1000;
	}

	.show-api.svelte-zxu34v {
		display: flex;
		align-items: center;
	}

	@media (max-width: 640px) {
		.show-api.svelte-zxu34v,
		.show-api-divider.svelte-zxu34v {
			display: none;
		}
	}

	.show-api.svelte-zxu34v:hover {
		color: var(--body-text-color);
	}

	.hidden.svelte-zxu34v {
		display: none;
	}