import { ap as Utils, aq as Color$1 } from './mermaid.core-vMMZVCDT-alxhRXoZ.js';

const channel = (color, channel2) => {
  return Utils.lang.round(Color$1.parse(color)[channel2]);
};

export { channel as c };
//# sourceMappingURL=channel-BBWJe5-y-CIm_TsAK.js.map
