import { b as baseClone } from './graph-DMRveAYX-DZW5LNz4.js';

var CLONE_SYMBOLS_FLAG = 4;
function clone(value) {
  return baseClone(value, CLONE_SYMBOLS_FLAG);
}

export { clone as c };
//# sourceMappingURL=clone-BWAcD7HO-DGqV5SEK.js.map
