
	div.svelte-1p9262q {
		border: var(--block-border-width) solid var(--border-color-primary);
		background: var(--block-border-color);
		border-radius: var(--block-radius);
		display: flex;
		flex-direction: column;
		gap: var(--form-gap-width);
		overflow: hidden;
	}
	div.svelte-1p9262q > *:not(.absolute) {
		border: none;
		border-radius: 0;
	}
	.hide.svelte-1p9262q {
		display: none;
	}