
	.wrap.svelte-ua961l {
		overflow-y: auto;
		transition: opacity 0.5s ease-in-out;
		background: var(--block-background-fill);
		position: relative;
		display: flex;
		flex-direction: column;
		align-items: center;
		justify-content: center;
		min-height: var(--size-40);
		width: var(--size-full);
	}

	.wrap.svelte-ua961l::after {
		content: "";
		position: absolute;
		top: 0;
		left: 0;
		width: var(--upload-progress-width);
		height: 100%;
		transition: all 0.5s ease-in-out;
		z-index: 1;
	}

	.uploading.svelte-ua961l {
		font-size: var(--text-lg);
		font-family: var(--font);
		z-index: 2;
	}

	.file-name.svelte-ua961l {
		margin: var(--spacing-md);
		font-size: var(--text-lg);
		color: var(--body-text-color-subdued);
	}

	.file.svelte-ua961l {
		font-size: var(--text-md);
		z-index: 2;
		display: flex;
		align-items: center;
	}

	.file.svelte-ua961l progress:where(.svelte-ua961l) {
		display: inline;
		height: var(--size-1);
		width: 100%;
		transition: all 0.5s ease-in-out;
		color: var(--color-accent);
		border: none;
	}

	.file.svelte-ua961l progress[value]:where(.svelte-ua961l)::-webkit-progress-value {
		background-color: var(--color-accent);
		border-radius: 20px;
	}

	.file.svelte-ua961l progress[value]:where(.svelte-ua961l)::-webkit-progress-bar {
		background-color: var(--border-color-accent);
		border-radius: 20px;
	}

	.progress-bar.svelte-ua961l {
		width: 14px;
		height: 14px;
		border-radius: 50%;
		background:
			radial-gradient(
				closest-side,
				var(--block-background-fill) 64%,
				transparent 53% 100%
			),
			conic-gradient(
				var(--color-accent) var(--upload-progress-width),
				var(--border-color-accent) 0
			);
		transition: all 0.5s ease-in-out;
	}
	button.svelte-8prmba {
		cursor: pointer;
		width: var(--size-full);
	}

	.center.svelte-8prmba {
		display: flex;
		justify-content: center;
	}
	.flex.svelte-8prmba {
		display: flex;
		flex-direction: column;
		justify-content: center;
		align-items: center;
	}
	.hidden.svelte-8prmba {
		display: none;
		position: absolute;
		flex-grow: 0;
	}

	.hidden.svelte-8prmba svg {
		display: none;
	}

	.disable_click.svelte-8prmba {
		cursor: default;
	}

	.icon-mode.svelte-8prmba {
		position: absolute !important;
		width: var(--size-4);
		height: var(--size-4);
		padding: 0;
		min-height: 0;
		border-radius: var(--radius-circle);
	}

	.icon-mode.svelte-8prmba svg {
		width: var(--size-4);
		height: var(--size-4);
	}