
	.wrap.svelte-1m8i4xt {
		padding: var(--size-6);
	}

	.attention.svelte-1m8i4xt {
		font-weight: var(--weight-bold);
		font-size: var(--text-lg);
	}

	.attention.svelte-1m8i4xt code:where(.svelte-1m8i4xt) {
		border: none;
		background: none;
		color: var(--color-accent);
		font-weight: var(--weight-bold);
	}

	button.svelte-1m8i4xt {
		position: absolute;
		top: var(--size-5);
		right: var(--size-6);
		width: var(--size-4);
		color: var(--body-text-color);
	}

	button.svelte-1m8i4xt:hover {
		color: var(--color-accent);
	}

	@media (min-width: 768px) {
		button.svelte-1m8i4xt {
			top: var(--size-6);
		}
	}
	h2.svelte-uv8a36 {
		display: flex;
		color: var(--body-text-color);
		font-weight: var(--weight-semibold);
		gap: var(--size-4);
	}

	h2.svelte-uv8a36 img:where(.svelte-uv8a36) {
		margin-right: var(--size-2);
		width: var(--size-4);
		display: inline-block;
	}

	.url.svelte-uv8a36 {
		color: var(--color-accent);
		font-weight: normal;
	}

	button.svelte-uv8a36 {
		position: absolute;
		top: var(--size-5);
		right: var(--size-6);
		width: var(--size-4);
		color: var(--body-text-color);
	}

	button.svelte-uv8a36:hover {
		color: var(--color-accent);
	}

	@media (min-width: 768px) {
		button.svelte-uv8a36 {
			top: var(--size-6);
		}

		h2.svelte-uv8a36 img:where(.svelte-uv8a36) {
			width: var(--size-5);
		}
	}

	.counts.svelte-uv8a36 {
		margin-top: auto;
		margin-right: var(--size-8);
		margin-bottom: auto;
		margin-left: auto;
		color: var(--body-text-color);
		font-weight: var(--weight-light);
		display: flex;
		flex-direction: row;
		gap: 0.5rem;
	}

	.loading-dot.svelte-uv8a36 {
		position: relative;
		left: -9999px;
		width: 12px;
		height: 12px;
		border-radius: 6px;
		background-color: #fd7b00;
		color: #fd7b00;
		box-shadow: 9999px 0 0 -1px;
		margin-right: 0.3rem;
	}

	.self-baseline.svelte-uv8a36 {
		align-self: baseline;
	}
	.title.svelte-uv8a36 {
		display: flex;
		flex-direction: row;
		gap: 0.5rem;
	}
	.btn-text.svelte-uv8a36 {
		font-size: var(--text-lg);
	}
	.hr.svelte-1nfxyth {
		border: 0;
		height: 1px;
		background: var(--color-accent-soft);
		margin-bottom: 12px;
	}

	.code.svelte-1nfxyth {
		font-family: var(--font-mono);
		display: inline;
	}

	.highlight.svelte-1nfxyth {
		background: var(--color-accent-soft);
		color: var(--color-accent);
		padding: var(--size-1);
	}

	.desc.svelte-1nfxyth {
		color: var(--body-text-color-subdued);
		font-size: var(--text-lg);
		margin-top: var(--size-1);
	}

	h4.svelte-1nfxyth {
		display: flex;
		align-items: center;
		margin-top: var(--size-6);
		margin-bottom: var(--size-3);
		color: var(--body-text-color);
		font-weight: var(--weight-bold);
	}

	.toggle-icon.svelte-1nfxyth {
		display: flex;
		align-items: center;
		margin-right: var(--size-2);
		border-radius: var(--radius-full);
		background: var(--color-grey-300);
		width: 12px;
		height: 4px;
	}

	.toggle-dot.svelte-1nfxyth {
		border-radius: var(--radius-full);
		background: var(--color-grey-700);
		width: 6px;
		height: 6px;
		margin-right: auto;
	}
	.icon-size.svelte-etvp4k {
		width: 0.75rem;
		height: 0.75rem;
	}

	@media (max-width: 640px) {
		.icon-size.svelte-etvp4k {
			width: 0.625rem;
			height: 0.625rem;
		}
	}
	.icon-size.svelte-5quqiz {
		width: 0.75rem;
		height: 0.75rem;
	}

	@media (max-width: 640px) {
		.icon-size.svelte-5quqiz {
			width: 0.625rem;
			height: 0.625rem;
		}
	}
	.copy-button.svelte-egghn7 {
		display: inline-flex;
		align-items: center;
		gap: 4px;
		height: 24px;
		padding-left: 8px;
		padding-right: 8px;
		font-size: 11px;
		font-weight: 500;
		color: rgb(31, 41, 55);
		border: 1px solid rgb(229, 231, 235);
		border-radius: 6px;
		background-color: white;

		@media (max-width: 640px) {
			gap: 2px;
			height: 20px;
			padding-left: 6px;
			padding-right: 6px;
			font-size: 9px;
			border-top-left-radius: 4px;
			border-bottom-left-radius: 4px;
		}

		&:hover {
			box-shadow: inset 0 2px 4px 0 rgb(0 0 0 / 0.05);
		}

		@media (prefers-color-scheme: dark) {
			border-color: rgb(38, 38, 38);
			background-color: rgb(10, 10, 10);
			color: rgb(229, 231, 235);

			&:hover {
				background-color: rgb(38, 38, 38);
			}
		}
	}
	code.svelte-1ts4a2g pre:where(.svelte-1ts4a2g) {
		overflow-x: auto;
		color: var(--body-text-color);
		font-family: var(--font-mono);
		tab-size: 2;
	}

	code.svelte-1ts4a2g {
		position: relative;
		display: block;
	}

	.copy.svelte-1ts4a2g {
		position: absolute;
		top: 0;
		right: 0;
		margin-top: -5px;
		margin-right: -5px;
	}
	.tooltip-chart.svelte-1q3jha5 {
		background: var(--background-fill-primary);
		border: 1px solid var(--border-color-primary);
		border-radius: var(--radius-md);
		padding: var(--size-3);
		box-shadow: var(--shadow-drop-lg);
		min-width: 200px;
		position: relative;
	}

	.tooltip-arrow.svelte-1q3jha5 {
		position: absolute;
		bottom: -8px;
		left: 50%;
		transform: translateX(-50%);
		width: 0;
		height: 0;
		border-left: 8px solid transparent;
		border-right: 8px solid transparent;
		border-top: 8px solid var(--border-color-primary);
	}

	.tooltip-arrow.svelte-1q3jha5::after {
		content: "";
		position: absolute;
		bottom: 1px;
		left: 50%;
		transform: translateX(-50%);
		width: 0;
		height: 0;
		border-left: 7px solid transparent;
		border-right: 7px solid transparent;
		border-top: 7px solid var(--background-fill-primary);
	}

	.chart-bars.svelte-1q3jha5 {
		display: flex;
		flex-direction: column;
		gap: var(--size-2);
	}

	.chart-bar-container.svelte-1q3jha5 {
		display: flex;
		align-items: center;
		gap: var(--size-2);
	}

	.chart-bar-label.svelte-1q3jha5 {
		font-size: var(--text-sm);
		font-weight: var(--weight-semibold);
		color: var(--body-text-color);
		min-width: 30px;
	}

	.chart-bar-wrapper.svelte-1q3jha5 {
		flex: 1;
		height: 16px;
		background: var(--background-fill-secondary);
		border-radius: var(--radius-sm);
		overflow: hidden;
		position: relative;
	}

	.chart-bar.svelte-1q3jha5 {
		height: 100%;
		background: var(--color-accent);
		border-radius: var(--radius-sm);
		transition: width 0.3s ease;
	}

	.chart-bar-value.svelte-1q3jha5 {
		font-size: var(--text-sm);
		color: var(--body-text-color);
		min-width: 50px;
		text-align: right;
		font-family: var(--font-mono);
	}
	h3.svelte-13swnto {
		color: var(--body-text-color);
		font-weight: var(--section-header-text-weight);
		font-size: var(--text-lg);
	}

	.post.svelte-13swnto {
		margin-right: var(--size-2);
		border: 1px solid var(--border-color-accent);
		border-radius: var(--radius-sm);
		background: var(--color-accent-soft);
		padding-right: var(--size-1);
		padding-bottom: var(--size-1);
		padding-left: var(--size-1);
		color: var(--color-accent);
		font-weight: var(--weight-semibold);
	}

	.analytics-inline.svelte-13swnto {
		display: inline-flex;
		align-items: center;
		gap: var(--size-2);
		margin-left: var(--size-2);
		color: var(--body-text-color-subdued);
	}

	.analytics-content.svelte-13swnto {
		position: relative;
		display: inline-block;
	}

	.analytics-text-wrapper.svelte-13swnto {
		cursor: help;
	}

	.analytics-tooltip.svelte-13swnto {
		position: absolute;
		bottom: 100%;
		left: 50%;
		transform: translateX(-50%);
		margin-bottom: var(--size-2);
		opacity: 0;
		pointer-events: none;
		transition: opacity 0.2s ease;
		z-index: 1000;
	}

	.analytics-content.svelte-13swnto:hover .analytics-tooltip:where(.svelte-13swnto) {
		opacity: 1;
		pointer-events: auto;
	}

	.most-recently-used.svelte-13swnto {
		display: inline-block;
		color: #fd7b00;
		background: #fff4e6;
		border: 1px solid #ffd9b3;
		border-radius: var(--radius-sm);
		padding: var(--size-1) var(--size-2);
		font-size: var(--text-sm);
		font-weight: var(--weight-medium);
		white-space: nowrap;
	}

	.desc.svelte-13swnto {
		color: var(--body-text-color);
		font-size: var(--text-lg);
		margin-left: var(--size-2);
	}
	code.svelte-1v9rhoq pre:where(.svelte-1v9rhoq) {
		overflow-x: auto;
		color: var(--body-text-color);
		font-family: var(--font-mono);
		tab-size: 2;
	}

	code.svelte-1v9rhoq {
		position: relative;
		display: block;
	}

	.copy.svelte-1v9rhoq {
		position: absolute;
		top: 0;
		right: 0;
		margin-top: -5px;
		margin-right: -5px;
	}

	.container.svelte-1v9rhoq {
		display: flex;
		flex-direction: column;
		gap: var(--spacing-xxl);
		margin-top: var(--size-3);
		margin-bottom: var(--size-3);
	}

	.api-name {
		color: var(--color-accent);
	}

	.str {
		color: var(--color-accent-base);
	}

	.hidden.svelte-1v9rhoq {
		display: none;
	}
	code.svelte-154to14 pre:where(.svelte-154to14) {
		overflow-x: auto;
		color: var(--body-text-color);
		font-family: var(--font-mono);
		tab-size: 2;
	}

	.token.string.svelte-154to14 {
		display: contents;
		color: var(--color-accent-base);
	}

	code.svelte-154to14 {
		position: relative;
		display: block;
	}

	.copy.svelte-154to14 {
		position: absolute;
		top: 0;
		right: 0;
		margin-top: -5px;
		margin-right: -5px;
	}

	.container.svelte-154to14 {
		display: flex;
		flex-direction: column;
		gap: var(--spacing-xxl);
		margin-top: var(--size-3);
		margin-bottom: var(--size-3);
	}

	.api-name.svelte-154to14 {
		color: var(--color-accent);
	}
	.hr.svelte-17pn6bc {
		border: 0;
		height: 1px;
		background: var(--color-accent-soft);
	}
	.code.svelte-17pn6bc {
		font-family: var(--font-mono);
		margin-right: 10px;
	}

	.highlight.svelte-17pn6bc {
		background: var(--color-accent-soft);
		color: var(--color-accent);
		padding: var(--size-1);
	}

	.desc.svelte-17pn6bc {
		color: var(--body-text-color-subdued);
		font-size: var(--text-lg);
	}

	h4.svelte-17pn6bc {
		display: flex;
		align-items: center;
		margin-top: var(--size-6);
		margin-bottom: var(--size-3);
		color: var(--body-text-color);
		font-weight: var(--weight-bold);
	}

	.toggle-icon.svelte-17pn6bc {
		display: flex;
		align-items: center;
		margin-right: var(--size-2);
		border-radius: var(--radius-full);
		background: var(--color-grey-300);
		width: 12px;
		height: 4px;
	}

	.toggle-dot.svelte-17pn6bc {
		border-radius: var(--radius-full);
		background: var(--color-grey-700);
		width: 6px;
		height: 6px;
		margin-left: auto;
	}
	.skill-content.svelte-1cyp2hi {
		margin-top: var(--size-2);
	}

	p.padded.svelte-1cyp2hi {
		padding: 15px 0px;
		font-size: var(--text-lg);
	}

	.hint.svelte-1cyp2hi {
		margin-top: var(--size-2);
		color: var(--body-text-color);
		opacity: 0.8;
		font-size: var(--text-md);
		line-height: 1.6;
	}

	.inline-code.svelte-1cyp2hi {
		display: inline;
		font-family: var(--font-mono);
		font-size: var(--text-md);
		background: var(--background-fill-secondary);
		padding: 1px 4px;
		border-radius: var(--radius-sm);
	}

	code.svelte-1cyp2hi pre:where(.svelte-1cyp2hi) {
		overflow-x: auto;
		color: var(--body-text-color);
		font-family: var(--font-mono);
		tab-size: 2;
	}

	code.svelte-1cyp2hi {
		position: relative;
		display: block;
	}

	.copy.svelte-1cyp2hi {
		position: absolute;
		top: 0;
		right: 0;
		margin-top: -5px;
		margin-right: -5px;
	}
	.tool-analytics-wrapper.svelte-1uo4thf {
		position: relative;
		display: inline-block;
	}

	.tool-analytics.svelte-1uo4thf {
		font-size: 0.95em;
		color: var(--body-text-color-subdued);
	}

	.transport-selection.svelte-1uo4thf {
		margin-bottom: var(--size-4);
	}

	.snippets.svelte-1uo4thf {
		display: flex;
		align-items: center;
		margin-bottom: var(--size-4);
	}

	.snippets.svelte-1uo4thf > :where(.svelte-1uo4thf) + :where(.svelte-1uo4thf) {
		margin-left: var(--size-2);
	}

	.transport-label.svelte-1uo4thf {
		font-weight: 600;
		color: var(--body-text-color);
		margin-right: var(--size-2);
	}

	.file-upload-section.svelte-1uo4thf {
		margin-top: var(--size-4);
		padding: var(--size-3);
		border: 1px solid var(--border-color-primary);
		border-radius: var(--radius-md);
		background: var(--background-fill-secondary);
	}

	.checkbox-label.svelte-1uo4thf {
		display: flex;
		align-items: center;
		font-weight: 600;
		color: var(--body-text-color);
		cursor: pointer;
		margin-bottom: var(--size-2);
	}

	.checkbox.svelte-1uo4thf {
		margin-right: var(--size-2);
		width: var(--size-4);
		height: var(--size-4);
		cursor: pointer;
		accent-color: var(--color-accent);
	}

	.checkbox.svelte-1uo4thf:checked {
		background-color: var(--color-accent);
		border-color: var(--color-accent);
	}

	.file-upload-explanation.svelte-1uo4thf {
		margin: 0;
		color: var(--body-text-color);
	}

	.snippet.svelte-1uo4thf {
		display: flex;
		align-items: center;
		border: 1px solid var(--border-color-primary);
		border-radius: var(--radius-md);
		padding: var(--size-1) var(--size-1-5);
		color: var(--body-text-color-subdued);
		color: var(--body-text-color);
		line-height: 1;
		user-select: none;
	}

	.current-lang.svelte-1uo4thf {
		border: 1px solid var(--body-text-color-subdued);
		color: var(--body-text-color);
	}

	.inactive-lang.svelte-1uo4thf {
		cursor: pointer;
		color: var(--body-text-color-subdued);
	}

	.inactive-lang.svelte-1uo4thf:hover,
	.inactive-lang.svelte-1uo4thf:focus {
		box-shadow: var(--shadow-drop);
		color: var(--body-text-color);
	}

	code.svelte-1uo4thf pre:where(.svelte-1uo4thf) {
		overflow-x: auto;
		color: var(--body-text-color);
		font-family: var(--font-mono);
		tab-size: 2;
	}

	.copy.svelte-1uo4thf {
		position: absolute;
		top: 0;
		right: 0;
		margin-top: 5px;
		margin-right: 5px;
		z-index: 10;
	}

	.mcp-url.svelte-1uo4thf {
		padding: var(--size-2);
		position: relative;
	}

	.mcp-url.svelte-1uo4thf label:where(.svelte-1uo4thf) {
		display: block;
		margin-bottom: var(--size-2);
		font-weight: 600;
		color: var(--body-text-color);
	}

	.mcp-url.svelte-1uo4thf .textbox:where(.svelte-1uo4thf) {
		display: flex;
		align-items: center;
		gap: var(--size-2);
		border: 1px solid var(--border-color-primary);
		border-radius: var(--radius-sm);
		padding: var(--size-2);
		background: var(--background-fill-primary);
	}

	.mcp-url.svelte-1uo4thf input:where(.svelte-1uo4thf) {
		flex: 1;
		border: none;
		background: none;
		color: var(--body-text-color);
		font-family: var(--font-mono);
		font-size: var(--text-md);
		width: 100%;
	}

	.mcp-url.svelte-1uo4thf input:where(.svelte-1uo4thf):focus {
		outline: none;
	}

	.status-indicator.svelte-1uo4thf {
		display: inline-block;
		margin-right: var(--size-1-5);
		position: relative;
		top: -1px;
		font-size: 0.8em;
	}

	.status-indicator.active.svelte-1uo4thf {
		color: #4caf50;
		animation: svelte-1uo4thf-pulse 1s infinite;
	}

	@keyframes svelte-1uo4thf-pulse {
		0% {
			opacity: 1;
		}
		50% {
			opacity: 0.6;
		}
		100% {
			opacity: 1;
		}
	}

	.mcp-tools.svelte-1uo4thf {
		margin-top: var(--size-4);
		border: 1px solid var(--border-color-primary);
		border-radius: var(--radius-md);
		overflow: hidden;
	}

	.tool-selection.svelte-1uo4thf {
		display: flex;
		justify-content: space-between;
		align-items: center;
		margin-bottom: var(--size-2);
	}

	.tool-selection-controls.svelte-1uo4thf {
		display: flex;
		gap: var(--size-2);
	}

	.select-all-btn.svelte-1uo4thf,
	.select-none-btn.svelte-1uo4thf {
		padding: var(--size-1) var(--size-2);
		border: 1px solid var(--border-color-primary);
		border-radius: var(--radius-sm);
		background: var(--background-fill-primary);
		color: var(--body-text-color);
		cursor: pointer;
		font-size: var(--text-sm);
	}

	.select-all-btn.svelte-1uo4thf:hover,
	.select-none-btn.svelte-1uo4thf:hover {
		background: var(--background-fill-secondary);
	}

	.tool-item.svelte-1uo4thf {
		border-bottom: 1px solid var(--border-color-primary);
	}

	.tool-item.svelte-1uo4thf:last-child {
		border-bottom: none;
	}

	.tool-header-wrapper.svelte-1uo4thf {
		display: flex;
		align-items: center;
	}

	.tool-checkbox.svelte-1uo4thf {
		margin-left: var(--size-3);
		margin-right: var(--size-2);
		width: var(--size-4);
		height: var(--size-4);
		cursor: pointer;
		accent-color: var(--color-accent);
	}

	.tool-checkbox.svelte-1uo4thf:checked {
		background-color: var(--color-accent);
		border-color: var(--color-accent);
	}

	.tool-header.svelte-1uo4thf {
		flex: 1;
		display: flex;
		justify-content: space-between;
		align-items: center;
		padding: var(--size-3);
		background: var(--background-fill-primary);
		border: none;
		cursor: pointer;
		text-align: left;
	}

	.tool-header.svelte-1uo4thf:hover {
		background: var(--background-fill-secondary);
	}

	.tool-name.svelte-1uo4thf {
		font-family: var(--font-mono);
		font-weight: 600;
	}

	.tool-arrow.svelte-1uo4thf {
		color: var(--body-text-color-subdued);
	}

	.tool-content.svelte-1uo4thf {
		padding: var(--size-3);
		background: var(--background-fill-secondary);
	}

	.tool-description.svelte-1uo4thf {
		margin-bottom: var(--size-3);
		color: var(--body-text-color);
	}
	.parameter.svelte-1uo4thf {
		margin-bottom: var(--size-2);
		padding: var(--size-2);
		background: var(--background-fill-primary);
		border-radius: var(--radius-sm);
	}

	.parameter.svelte-1uo4thf code:where(.svelte-1uo4thf) {
		font-weight: 600;
		color: var(--color-accent);
	}

	.parameter-type.svelte-1uo4thf {
		color: var(--body-text-color-subdued);
		margin-left: var(--size-1);
	}

	.parameter-description.svelte-1uo4thf {
		margin-top: var(--size-1);
		color: var(--body-text-color);
	}

	a.svelte-1uo4thf {
		text-decoration: underline;
	}

	.hidden.svelte-1uo4thf {
		display: none;
	}
	.menu-icon-arrow.svelte-1s9m4x9 {
		width: 1rem;
		height: 1rem;
		color: rgb(107, 114, 128);
		flex-shrink: 0;
	}

	@media (prefers-color-scheme: dark) {
		.menu-icon-arrow.svelte-1s9m4x9 {
			color: rgb(209, 213, 219);
		}
	}
	.caret-icon.svelte-1u0oj9c {
		transition: transform 0.2s ease-in-out;
		color: rgb(156, 163, 175);
		overflow: visible;
		width: 0.75rem;
		height: 0.75rem;
	}

	@media (max-width: 640px) {
		.caret-icon.svelte-1u0oj9c {
			width: 0.625rem;
			height: 0.625rem;
		}
	}

	.rotate-180.svelte-1u0oj9c {
		transform: rotate(180deg);
	}

	.rotate-0.svelte-1u0oj9c {
		transform: rotate(0deg);
	}
	.icon-size.svelte-pw1cre {
		width: 0.75rem;
		height: 0.75rem;
	}

	@media (max-width: 640px) {
		.icon-size.svelte-pw1cre {
			width: 0.625rem;
			height: 0.625rem;
		}
	}

	.menu-icon.svelte-pw1cre {
		width: 1rem;
		height: 1rem;
		flex-shrink: 0;
	}

	.hidden.svelte-pw1cre {
		display: none;
	}

	.block.svelte-pw1cre {
		display: block;
	}
	.container-wrapper.svelte-de9ybk {
		display: flex;
		align-items: center;
		flex-shrink: 0;
		min-width: 100px;
		justify-content: flex-end;
		margin-left: auto;
	}

	@media (max-width: 640px) {
		.container-wrapper.svelte-de9ybk {
			min-width: 50px;
		}
	}

	.trigger-wrapper.svelte-de9ybk {
		display: inline-flex;
		border-radius: 0.375rem;
	}

	@media (max-width: 640px) {
		.trigger-wrapper.svelte-de9ybk {
			border-radius: 0.125rem;
		}
	}

	.icon-wrapper.svelte-de9ybk {
		display: inline-flex;
		align-items: center;
		justify-content: center;
		border-radius: 0.375rem;
		padding: 0.125rem;
	}

	@media (max-width: 640px) {
		.icon-wrapper.svelte-de9ybk {
			padding: 0;
		}
	}

	.menu-toggle-button.svelte-de9ybk {
		display: inline-flex;
		align-items: center;
		justify-content: center;
		width: 1.5rem;
		height: 1.5rem;
		font-size: 0.875rem;
		color: rgb(107, 114, 128);
		border-radius: 0;
		border-top-right-radius: 0.375rem;
		border-bottom-right-radius: 0.375rem;
		border: 1px solid rgb(229, 231, 235);
		border-left: none;
		background-color: white;
		transition: all 0.2s ease-in-out;
	}

	.menu-toggle-button.svelte-de9ybk:disabled {
		pointer-events: none;
	}

	.menu-toggle-button.svelte-de9ybk:hover {
		color: rgb(55, 65, 81);
		box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.05);
	}

	@media (max-width: 640px) {
		.menu-toggle-button.svelte-de9ybk {
			width: 1.25rem;
			height: 1.25rem;
			border-top-right-radius: 0.125rem;
			border-bottom-right-radius: 0.125rem;
		}
	}

	@media (prefers-color-scheme: dark) {
		.menu-toggle-button.svelte-de9ybk {
			border-color: rgb(38, 38, 38);
			background-color: rgb(10, 10, 10);
			color: rgb(229, 231, 235);
		}

		.menu-toggle-button.svelte-de9ybk:hover {
			color: white;
			background-color: rgb(31, 41, 55);
		}
	}

	.backdrop-overlay.svelte-de9ybk {
		position: fixed;
		top: 0;
		right: 0;
		bottom: 0;
		left: 0;
		z-index: 40;
	}

	.menu-dropdown.svelte-de9ybk {
		position: fixed;
		z-index: 50;
		backdrop-filter: blur(24px);
		border-radius: 0.75rem;
		max-height: 420px;
		overflow-y: auto;
		padding: 0.25rem;
		border: 1px solid rgb(229, 231, 235);
		display: flex;
		flex-direction: column;
		background-color: white;
		color: rgb(31, 41, 55);
	}

	@media (prefers-color-scheme: dark) {
		.menu-dropdown.svelte-de9ybk {
			border-color: rgb(38, 38, 38);
			background-color: rgb(10, 10, 10);
			color: rgb(229, 231, 235);
		}
	}

	.menu-icon-container.svelte-de9ybk {
		border: 1px solid rgb(229, 231, 235);
		border-radius: 0.5rem;
		padding: 0.375rem;
	}

	@media (prefers-color-scheme: dark) {
		.menu-icon-container.svelte-de9ybk {
			border-color: rgb(38, 38, 38);
		}
	}

	.menu-text-container.svelte-de9ybk {
		display: flex;
		flex-direction: column;
		padding-left: 0.25rem;
		padding-right: 0.25rem;
	}

	.menu-text-primary.svelte-de9ybk {
		font-size: 11px;
		font-weight: 500;
		color: rgb(31, 41, 55);
		display: flex;
		align-items: center;
		gap: 0.25rem;
	}

	@media (prefers-color-scheme: dark) {
		.menu-text-primary.svelte-de9ybk {
			color: rgb(209, 213, 219);
		}
	}

	.menu-text-secondary.svelte-de9ybk {
		font-size: 0.75rem;
		color: rgb(75, 85, 99);
	}

	@media (prefers-color-scheme: dark) {
		.menu-text-secondary.svelte-de9ybk {
			color: rgb(156, 163, 175);
		}
	}

	.copy-button.svelte-de9ybk {
		display: inline-flex;
		align-items: center;
		gap: 4px;
		height: 24px;
		padding-left: 8px;
		padding-right: 6px;
		font-size: 11px;
		font-weight: 500;
		color: rgb(31, 41, 55);
		border: 1px solid rgb(229, 231, 235);
		border-radius: 6px;
		border-top-right-radius: 0;
		border-bottom-right-radius: 0;
		background-color: white;

		@media (max-width: 640px) {
			gap: 2px;
			height: 20px;
			padding-left: 6px;
			padding-right: 6px;
			font-size: 9px;
			border-top-left-radius: 4px;
			border-bottom-left-radius: 4px;
		}

		&:hover {
			box-shadow: inset 0 2px 4px 0 rgb(0 0 0 / 0.05);
		}

		@media (prefers-color-scheme: dark) {
			border-color: rgb(38, 38, 38);
			background-color: rgb(10, 10, 10);
			color: rgb(229, 231, 235);

			&:hover {
				background-color: rgb(38, 38, 38);
			}
		}
	}

	.base-menu-item.svelte-de9ybk {
		cursor: pointer;
		font-size: 11px;
		position: relative;
		width: 100%;
		user-select: none;
		outline: none;
		display: flex;
		align-items: center;
		gap: 0.375rem;
		padding-left: 0.375rem;
		padding-right: 0.375rem;
		padding-top: 0.375rem;
		padding-bottom: 0.375rem;
		border-radius: 0.75rem;
		text-align: left;
		transition: all 0.2s ease-in-out;
		border-color: #e5e7eb;
		background-color: #ffffff;
	}

	.base-menu-item.svelte-de9ybk:hover {
		box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.05);
	}

	@media (prefers-color-scheme: dark) {
		.base-menu-item.svelte-de9ybk {
			border-color: #1f2937;
			background-color: #0f1117;
			color: #e5e7eb;
		}

		.base-menu-item.svelte-de9ybk:hover {
			background-color: #1f2937;
		}
	}
	.banner-wrap.svelte-1ujc8oz {
		position: relative;
		border-bottom: 1px solid var(--border-color-primary);
		padding: var(--size-4) var(--size-6);
		font-size: var(--text-md);
	}

	@media (min-width: 768px) {
		.banner-wrap.svelte-1ujc8oz {
			font-size: var(--text-xl);
		}
	}

	.docs-wrap.svelte-1ujc8oz {
		display: flex;
		flex-direction: column;
		gap: var(--spacing-xxl);
	}

	.endpoint.svelte-1ujc8oz {
		border-radius: var(--radius-md);
		background: var(--background-fill-primary);
		padding: var(--size-6);
		padding-top: var(--size-1);
		font-size: var(--text-md);
	}

	.client-doc.svelte-1ujc8oz {
		padding-top: var(--size-6);
		padding-right: var(--size-6);
		padding-left: var(--size-6);
		font-size: var(--text-md);
	}

	/* (unused) .library {
		border: 1px solid var(--border-color-accent);
		border-radius: var(--radius-sm);
		background: var(--color-accent-soft);
		padding: 0px var(--size-1);
		color: var(--color-accent);
		font-size: var(--text-md);
		text-decoration: none;
	}*/

	.snippets.svelte-1ujc8oz {
		display: flex;
		align-items: center;
		margin-bottom: var(--size-4);
	}

	.snippets.svelte-1ujc8oz > :where(.svelte-1ujc8oz) + :where(.svelte-1ujc8oz) {
		margin-left: var(--size-2);
	}

	.snippet.svelte-1ujc8oz {
		display: flex;
		align-items: center;
		border: 1px solid var(--border-color-primary);

		border-radius: var(--radius-md);
		padding: var(--size-1) var(--size-1-5);
		color: var(--body-text-color-subdued);
		color: var(--body-text-color);
		line-height: 1;
		user-select: none;
		font-size: var(--text-lg);
	}

	.current-lang.svelte-1ujc8oz {
		border: 1px solid var(--body-text-color-subdued);
		color: var(--body-text-color);
	}

	.inactive-lang.svelte-1ujc8oz {
		cursor: pointer;
		color: var(--body-text-color-subdued);
	}

	.inactive-lang.svelte-1ujc8oz:hover,
	.inactive-lang.svelte-1ujc8oz:focus {
		box-shadow: var(--shadow-drop);
		color: var(--body-text-color);
	}

	.snippet.svelte-1ujc8oz img:where(.svelte-1ujc8oz) {
		margin-right: var(--size-1-5);
		width: var(--size-4);
		height: var(--size-4);
	}

	/* (unused) .header {
		margin-top: var(--size-6);
		font-size: var(--text-xl);
	}*/

	.endpoint-container.svelte-1ujc8oz {
		margin-top: var(--size-3);
		margin-bottom: var(--size-3);
		border: 1px solid var(--block-border-color);
		border-radius: var(--radius-xl);
		padding: var(--size-3);
		padding-top: 0;
	}

	a.svelte-1ujc8oz {
		text-decoration: underline;
	}

	p.padded.svelte-1ujc8oz {
		padding: 15px 0px;
		font-size: var(--text-lg);
	}

	/* (unused) #api-recorder {
		border: 1px solid var(--color-accent);
		background-color: var(--color-accent-soft);
		padding: 0px var(--size-2);
		border-radius: var(--size-1);
		cursor: pointer;
	}*/

	code.svelte-1ujc8oz {
		font-size: var(--text-md);
	}
	.loading-dot.svelte-1ujc8oz {
		position: relative;
		left: -9999px;
		width: 10px;
		height: 10px;
		border-radius: 5px;
		background-color: #fd7b00;
		color: #fd7b00;
		box-shadow: 9999px 0 0 -1px;
		margin-right: 0.25rem;
	}
	.docs-wrap .sm.secondary {
		padding-top: 1px;
		padding-bottom: 1px;
	}
	.self-baseline.svelte-1ujc8oz {
		align-self: baseline;
	}
	.api-count.svelte-1ujc8oz {
		font-weight: bold;
		color: #fd7b00;
		align-self: baseline;
		font-family: var(--font-mono);
		font-size: var(--text-md);
	}

	/* (unused) code pre {
		overflow-x: auto;
		color: var(--body-text-color);
		font-family: var(--font-mono);
		tab-size: 2;
	}*/

	/* (unused) .token.string {
		display: contents;
		color: var(--color-accent-base);
	}*/

	/* (unused) .copy {
		position: absolute;
		top: 0;
		right: 0;
		margin-top: 5px;
		margin-right: 5px;
		z-index: 10;
	}*/

	/* (unused) .container {
		display: flex;
		flex-direction: column;
		gap: var(--spacing-xxl);
		margin-top: var(--size-3);
		margin-bottom: var(--size-3);
	}*/

	/* (unused) .desc {
		color: var(--body-text-color-subdued);
	}*/

	/* (unused) .api-name {
		color: var(--color-accent);
	}*/

	.hidden.svelte-1ujc8oz {
		display: none;
	}