
	table.svelte-wcwkqi {
		position: relative;
		border-collapse: collapse;
	}

	td.svelte-wcwkqi {
		border: 1px solid var(--table-border-color);
		padding: var(--size-2);
		font-size: var(--text-sm);
		font-family: var(--font-mono);
	}

	.selected.svelte-wcwkqi td:where(.svelte-wcwkqi) {
		border-color: var(--border-color-accent);
	}

	.table.svelte-wcwkqi {
		display: inline-block;
		margin: 0 auto;
	}

	.gallery.svelte-wcwkqi td:where(.svelte-wcwkqi):first-child {
		border-left: none;
	}

	.gallery.svelte-wcwkqi tr:where(.svelte-wcwkqi):first-child td:where(.svelte-wcwkqi) {
		border-top: none;
	}

	.gallery.svelte-wcwkqi td:where(.svelte-wcwkqi):last-child {
		border-right: none;
	}

	.gallery.svelte-wcwkqi tr:where(.svelte-wcwkqi):last-child td:where(.svelte-wcwkqi) {
		border-bottom: none;
	}

	.overlay.svelte-wcwkqi {
		--gradient-to: transparent;
		position: absolute;
		bottom: 0;
		background: linear-gradient(to bottom, transparent, var(--gradient-to));
		width: var(--size-full);
		height: 50%;
	}

	/* i dont know what i've done here but it is what it is */
	.odd.svelte-wcwkqi {
		--gradient-to: var(--table-even-background-fill);
	}

	.even.svelte-wcwkqi {
		--gradient-to: var(--table-odd-background-fill);
	}

	.button.svelte-wcwkqi {
		--gradient-to: var(--background-fill-primary);
	}